@@ -76,9 +76,6 @@ from bzrlib.repository import (
 from bzrlib.revisionspec import (
     revspec_registry,
     )
-from bzrlib.trace import (
-    mutter,
-    )
 from bzrlib.transport import (
     register_lazy_transport,
     register_transport_proto,
@@ -102,6 +99,7 @@ def check_subversion_version():
                 'bzr-svn: Installed Subversion has buggy svn.ra.get_log() '
                 'implementation, please install newer.')
 
+    from bzrlib.trace import mutter
     mutter("bzr-svn: using Subversion %d.%d.%d (%s)" % ra_version)
 
     if subvertpy_version < subvertpy_minimum_version:
@@ -117,7 +115,7 @@ def init_subvertpy():
     try:
         import subvertpy
     except ImportError, e:
-        raise DependencyNotPresent("subvertpy", "bzr-svn: %s" % e.message)
+        raise DependencyNotPresent("subvertpy", "bzr-svn: %s" % str(e))
 
     check_subversion_version()
 
@@ -140,10 +138,8 @@ from bzrlib.plugins.svn import format
 
 register_transport_proto('svn+ssh://',
     help="Access using the Subversion smart server tunneled over SSH.")
-register_transport_proto('svn+http://',
-    help="Access of Subversion smart servers over HTTP.")
-register_transport_proto('svn+https://',
-    help="Access of Subversion smart servers over secure HTTP.")
+register_transport_proto('svn+http://')
+register_transport_proto('svn+https://')
 register_transport_proto('svn://',
     help="Access using the Subversion smart server.")
 register_lazy_transport('svn://', 'bzrlib.plugins.svn.transport',
@@ -233,7 +229,6 @@ def update_stanza(rev, stanza):
         stanza.add("svn-uuid", revmeta.uuid)
     else:
         from bzrlib.plugins.svn.mapping import mapping_registry
-        from bzrlib.plugins.svn import errors as svn_errors
         try:
             (uuid, branch_path, revno), mapping = \
                 mapping_registry.parse_revision_id(rev.revision_id)
@@ -253,6 +248,14 @@ from bzrlib.send import format_registry as send_format_registry
 send_format_registry.register_lazy('svn', 'bzrlib.plugins.svn.send',
                                    'send_svn', 'Subversion diff format')
 
+try:
+    from bzrlib.diff import format_registry as diff_format_registry
+except ImportError:
+    pass # Not available prior to bzr 2.2b2
+else:
+    diff_format_registry.register_lazy('svn', 'bzrlib.plugins.svn.send',
+            'SvnDiffTree', 'Subversion diff format')
+
 
 def test_suite():
     """Returns the testsuite for bzr-svn."""
