@@ -44,6 +44,7 @@ from bzrlib.branch import (
     )
 from bzrlib.bzrdir import (
     BzrDir,
+    format_registry,
     )
 from bzrlib.errors import (
     DivergedBranches,
@@ -68,6 +69,7 @@ from bzrlib.plugins.svn import (
     util,
     )
 from bzrlib.plugins.svn.fetch import (
+    FetchRevisionFinder,
     InterFromSvnRepository,
     )
 from bzrlib.plugins.svn.push import (
@@ -81,9 +83,6 @@ from bzrlib.plugins.svn.errors import (
     NotSvnBranchPath,
     PushToEmptyBranch,
     )
-from bzrlib.plugins.svn.format import (
-    get_rich_root_format,
-    )
 from bzrlib.plugins.svn.repository import (
     SvnRepository,
     )
@@ -117,6 +116,30 @@ class SubversionSourcePullResult(PullResult):
         self._show_tag_conficts(to_file)
 
 
+class SubversionWriteLock(object):
+    """A (dummy) write lock on a Subversion object."""
+
+    __slots__ = ('unlock')
+
+    def __init__(self, unlock):
+        self.unlock = unlock
+
+    def __repr__(self):
+        return "<%s>" % self.__class__.__name__
+
+
+class SubversionReadLock(object):
+    """A (dummy) read lock on a Subversion object."""
+
+    __slots__ = ('unlock')
+
+    def __init__(self, unlock):
+        self.unlock = unlock
+
+    def __repr__(self):
+        return "<%s>" % self.__class__.__name__
+
+
 class SubversionTargetBranchPushResult(BranchPushResult):
     """Subversion target branch push result."""
 
@@ -130,7 +153,13 @@ class SubversionTargetBranchPushResult(BranchPushResult):
 
     @property
     def old_revno(self):
-        return self._lookup_revno(self.old_revid)
+        try:
+            return self._lookup_revno(self.old_revid)
+        except NoSuchRevision:
+            # Last resort
+            return len(
+                self.target_branch.repository.iter_reverse_revision_history(
+                    self.old_revid))
 
     @property
     def new_revno(self):
@@ -149,7 +178,13 @@ class SubversionTargetPullResult(PullResult):
 
     @property
     def old_revno(self):
-        return self._lookup_revno(self.old_revid)
+        try:
+            return self._lookup_revno(self.old_revid)
+        except NoSuchRevision:
+            # Last resort
+            return len(
+                list(self.target_branch.repository.iter_reverse_revision_history(
+                    self.old_revid)))
 
     @property
     def new_revno(self):
@@ -171,6 +206,7 @@ class SvnBranch(ForeignBranch):
         :param _skip_check: If True, don't check if the branch actually exists.
         """
         self.repository = repository
+        self.bzrdir = repository.bzrdir
         self._format = SvnBranchFormat()
         self.layout = self.repository.get_layout()
         assert isinstance(self.repository, SvnRepository)
@@ -225,6 +261,8 @@ class SvnBranch(ForeignBranch):
         if revnum is None:
             return self._branch_path
 
+        assert revnum >= 0
+
         last_revmeta, _ = self.last_revmeta()
         if revnum == last_revmeta.revnum:
             return last_revmeta.branch_path
@@ -274,7 +312,8 @@ class SvnBranch(ForeignBranch):
         :return: WorkingTree object of checkout.
         """
         checkout_branch = BzrDir.create_branch_convenience(
-            to_location, force_new_tree=False, format=get_rich_root_format())
+            to_location, force_new_tree=False,
+            format=format_registry.make_bzrdir('default'))
         checkout = checkout_branch.bzrdir
         checkout_branch.bind(self)
         # pull up to the specified revision_id to set the initial
@@ -365,7 +404,8 @@ class SvnBranch(ForeignBranch):
     def set_revision_history(self, rev_history):
         """See Branch.set_revision_history()."""
         if (rev_history == [] or
-            not self.repository.has_revision(rev_history[-1], project=self.project)):
+            not self.repository.has_revision(rev_history[-1],
+                project=self.project)):
             raise NotImplementedError("set_revision_history can't add ghosts")
         rev = self.repository.get_revision(rev_history[-1])
         if rev.parent_ids:
@@ -558,6 +598,7 @@ class SvnBranch(ForeignBranch):
             self._lock_mode = 'w'
             self._lock_count = 1
         self.repository.lock_write()
+        return SubversionWriteLock(self.unlock)
 
     def lock_read(self):
         """See Branch.lock_read()."""
@@ -568,6 +609,7 @@ class SvnBranch(ForeignBranch):
             self._lock_mode = 'r'
             self._lock_count = 1
         self.repository.lock_read()
+        return SubversionReadLock(self.unlock)
 
     def unlock(self):
         """See Branch.unlock()."""
@@ -609,9 +651,6 @@ class SvnBranch(ForeignBranch):
 class SvnBranchFormat(BranchFormat):
     """Branch format for Subversion Branches."""
 
-    def __init__(self):
-        BranchFormat.__init__(self)
-
     def network_name(self):
         return "subversion"
 
@@ -659,8 +698,18 @@ class InterSvnOtherBranch(GenericInterBranch):
        history browsing operations
     """
 
-    def update_revisions(self, stop_revision=None, overwrite=False, graph=None):
-        """See InterBranch.update_revisions()."""
+    def update_revisions(self, stop_revision=None, overwrite=False,
+                         graph=None):
+        self._update_revisions(stop_revision, overwrite, graph)
+
+    def _update_revisions(self, stop_revision=None, overwrite=False,
+            graph=None, limit=None):
+        """Like InterBranch.update_revisions, but with a few additional
+            parameters.
+
+        :param limit: Optional maximum number of revisions to fetch
+        :return: Last revision
+        """
         self.source.lock_read()
         try:
             other_last_revision = self.source.last_revision()
@@ -668,29 +717,47 @@ class InterSvnOtherBranch(GenericInterBranch):
                 stop_revision = other_last_revision
                 if is_null(stop_revision):
                     # if there are no commits, we're done.
-                    return
+                    return self.target.last_revision_info()
 
             # what's the current last revision, before we fetch [and
             # change it possibly]
-            last_rev = ensure_null(self.target.last_revision())
+            last_rev = self.target.last_revision()
             # we fetch here so that we don't process data twice in the
             # common case of having something to pull, and so that the
             # check for already merged can operate on the just fetched
             # graph, which will be cached in memory.
+            revisionfinder = FetchRevisionFinder(self.source.repository,
+                self.target.repository)
+            pb = ui.ui_factory.nested_progress_bar()
+            try:
+                revisionfinder.find_until(
+                    self.source.last_revmeta()[0].get_foreign_revid(),
+                    self.source.mapping,
+                    find_ghosts=False, pb=pb)
+            finally:
+                pb.finished()
             interrepo = InterFromSvnRepository(self.source.repository,
-                                               self.target.repository)
-            interrepo.fetch(stop_revision, project=self.source.project,
-                            mapping=self.source.mapping)
+                self.target.repository)
+            missing = revisionfinder.get_missing(limit=limit)
+            if limit is not None and len(missing) > 0:
+                stop_revision = missing[-1][0].get_revision_id(missing[-1][1])
+            interrepo.fetch(needed=missing,
+                project=self.source.project, mapping=self.source.mapping)
             # Check to see if one is an ancestor of the other
             if not overwrite:
                 if graph is None:
                     graph = self.target.repository.get_graph()
-                if self.target._check_if_descendant_or_diverged(
-                        stop_revision, last_rev, graph, self.source):
-                    # stop_revision is a descendant of last_rev, but we
-                    # aren't overwriting, so we're done.
-                    return
+                self.target.lock_read()
+                try:
+                    if self.target._check_if_descendant_or_diverged(
+                            stop_revision, last_rev, graph, self.source):
+                        # stop_revision is a descendant of last_rev, but we
+                        # aren't overwriting, so we're done.
+                        return self.target.last_revision_info()
+                finally:
+                    self.target.unlock()
             self.target.generate_revision_history(stop_revision)
+            return self.target.last_revision_info()
         finally:
             self.source.unlock()
 
@@ -707,7 +774,7 @@ class InterSvnOtherBranch(GenericInterBranch):
 
     def pull(self, overwrite=False, stop_revision=None,
              _hook_master=None, run_hooks=True, possible_transports=None,
-             _override_hook_target=None, local=False):
+             _override_hook_target=None, local=False, limit=None):
         """See InterBranch.pull()."""
         if local:
             raise LocalRequiresBoundBranch()
@@ -737,25 +804,18 @@ class InterSvnOtherBranch(GenericInterBranch):
             if stop_revision == NULL_REVISION:
                 result.new_revid = NULL_REVISION
                 result.new_revmeta = None
-                tags_until_revnum = 0
             elif stop_revision is not None:
                 result.new_revmeta, _ = \
                     self.source.repository._get_revmeta(stop_revision)
-                tags_until_revnum = result.new_revmeta.revnum
             else:
                 result.new_revmeta = None
-                tags_until_revnum = self.source.repository.get_latest_revnum()
-            self.update_revisions(stop_revision, overwrite)
-            (result.new_revno, result.new_revid) = \
-                self.target.last_revision_info()
+            (result.new_revno, result.new_revid) = self._update_revisions(
+                stop_revision, overwrite, limit=limit)
             if self.source.supports_tags():
-                if result.old_revid == result.new_revid:
-                    # Upstream branch wasn't added but perhaps new tags were
-                    # added since.
-                    tags_since_revnum = self.source.get_revnum()
                 result.tag_conflicts = self.source.tags.merge_to(
-                    self.target.tags, overwrite, _from_revnum=tags_since_revnum,
-                    _to_revnum=tags_until_revnum)
+                    self.target.tags, overwrite,
+                    _from_revnum=tags_since_revnum,
+                    _to_revnum=self.source.repository.get_latest_revnum())
             if _hook_master:
                 result.master_branch = _hook_master
                 result.local_branch = result.target_branch
@@ -785,12 +845,12 @@ class InterOtherSvnBranch(InterBranch):
 
     @staticmethod
     def _get_branch_formats_to_test():
-        return None, None
+        return []
 
     def update_revisions(self, stop_revision=None, overwrite=False, graph=None):
         """See Branch.update_revisions()."""
-        self._update_revisions(stop_revision=stop_revision, overwrite=overwrite,
-            graph=graph)
+        self._update_revisions(stop_revision=stop_revision,
+            overwrite=overwrite, graph=graph)
 
     def _target_is_empty(self, graph, revid):
         parent_revids = tuple(graph.get_parent_map([revid])[revid])
@@ -830,8 +890,8 @@ class InterOtherSvnBranch(InterBranch):
             ((self.target.repository.uuid, last_branch_path, last_revnum), self.target.mapping))
         return interrepo
 
-    def _update_revisions(self, stop_revision=None, overwrite=False, graph=None,
-        push_merged=False, override_svn_revprops=None):
+    def _update_revisions(self, stop_revision=None, overwrite=False,
+            graph=None, push_merged=False, override_svn_revprops=None):
         old_last_revid = self.target.last_revision()
         if stop_revision is None:
             stop_revision = ensure_null(self.source.last_revision())
@@ -849,9 +909,10 @@ class InterOtherSvnBranch(InterBranch):
             self.target.repository.has_revision(stop_revision)):
             # Revision is already present in the repository, so just
             # copy from there.
-            new_last_revid, new_foreign_info = create_branch_with_hidden_commit(
-                self.target.repository, self.target.get_branch_path(),
-                stop_revision, set_metadata=True, deletefirst=True)
+            new_last_revid, new_foreign_info = \
+                create_branch_with_hidden_commit(self.target.repository,
+                    self.target.get_branch_path(), stop_revision,
+                    set_metadata=True, deletefirst=True)
         else:
             interrepo = self._get_interrepo(graph)
             assert todo != []
@@ -908,8 +969,7 @@ class InterOtherSvnBranch(InterBranch):
             interrepo = InterFromSvnRepository(self.target.repository,
                                                self.source.repository)
             interrepo.fetch(revision_id=revid_map[rev.revision_id],
-                            mapping=self.target.mapping,
-                            project=self.target.project)
+                mapping=self.target.mapping, project=self.target.project)
             self.target._clear_cached_state()
             assert stop_revision in revid_map
             assert len(revid_map.keys()) > 0
@@ -937,7 +997,8 @@ class InterOtherSvnBranch(InterBranch):
         return self.source.tags.merge_to(self.target.tags, overwrite)
 
     def push(self, overwrite=False, stop_revision=None,
-            _push_merged=None, _override_svn_revprops=None):
+            _push_merged=None, _override_svn_revprops=None,
+            _override_hook_source_branch=None):
         """See InterBranch.push()."""
         result = SubversionTargetBranchPushResult()
         result.target_branch = self.target
@@ -956,7 +1017,8 @@ class InterOtherSvnBranch(InterBranch):
 
     def pull(self, overwrite=False, stop_revision=None,
              _hook_master=None, run_hooks=True, possible_transports=None,
-             _push_merged=None, _override_svn_revprops=None, local=False):
+             _push_merged=None, _override_svn_revprops=None, local=False,
+             limit=None):
         """See InterBranch.pull()."""
         if local:
             raise LocalRequiresBoundBranch()
