@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2009 Jelmer Vernooij <jelmer@samba.org>
+# Copyright (C) 2007-2010 Jelmer Vernooij <jelmer@samba.org>
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,9 @@ from subvertpy import (
     properties,
     )
 
+import bzrlib.config
 from bzrlib import (
+    atomicfile,
     osutils,
     trace,
     )
@@ -72,7 +74,10 @@ def subversion_config_filename():
     return osutils.pathjoin(config_dir(), 'subversion.conf')
 
 
-class SubversionUUIDConfig(IniBasedConfig):
+config_base_class = getattr(bzrlib.config, "LockableConfig", IniBasedConfig)
+
+
+class SubversionUUIDConfig(config_base_class):
     """UUID-based Subversion configuration."""
 
     def __init__(self, uuid):
@@ -103,12 +108,13 @@ class SubversionUUIDConfig(IniBasedConfig):
         :param name: Name of the option.
         :param value: Value of the option.
         """
-        conf_dir = os.path.dirname(self._get_filename())
-        ensure_config_dir_exists(conf_dir)
+        file_name = self._get_filename()
+        ensure_config_dir_exists(os.path.dirname(file_name))
+        atomic_file = atomicfile.AtomicFile(file_name)
         self[name] = value
-        f = open(self._get_filename(), 'wb')
-        self._get_parser().write(f)
-        f.close()
+        self._get_parser().write(atomic_file)
+        atomic_file.commit()
+        atomic_file.close()
 
 
 class SvnRepositoryConfig(Config):
@@ -378,6 +384,9 @@ class BranchConfig(Config):
         """Get the user id from the 'email' key in the current section."""
         return self._get_user_option('email')
 
+    def _get_change_editor(self):
+        return self.get_user_option('change_editor')
+
     def set_user_option(self, name, value, store=STORE_LOCATION,
         warn_masked=False):
         if store == STORE_GLOBAL:
