@@ -55,9 +55,6 @@ from bzrlib.plugins.svn.fetch import (
     FetchRevisionFinder,
     InterFromSvnRepository,
     )
-from bzrlib.plugins.svn.format import (
-    get_rich_root_format,
-    )
 
 
 LATEST_IMPORT_REVISION_FILENAME = "svn-import-revision"
@@ -93,6 +90,7 @@ def put_latest_svn_import_revision(repo, uuid, revnum):
 class NotDumpFile(BzrError):
     """A file specified was not a dump file."""
     _fmt = """%(dumpfile)s is not a dump file."""
+
     def __init__(self, dumpfile):
         BzrError.__init__(self)
         self.dumpfile = dumpfile
@@ -156,7 +154,7 @@ class RepositoryConverter(object):
         """
         assert not all or create_shared_repo
         if format is None:
-            self._format = get_rich_root_format()
+            self._format = bzrdir.format_registry.make_bzrdir('default')
         else:
             self._format = format
         self.dirs = {}
@@ -301,14 +299,13 @@ class RepositoryConverter(object):
                 except NotBranchError:
                     target_branch = target_dir.create_branch()
                     target_branch.set_parent(source_branch.base)
-                if source_branch.last_revision() != target_branch.last_revision():
-                    try:
-                        target_branch.pull(source_branch, overwrite=True)
-                    except NoSuchRevision:
-                        if source_branch.check_path() == NODE_FILE:
-                            self.to_transport.delete_tree(source_branch.get_branch_path())
-                            continue
-                        raise
+                try:
+                    target_branch.pull(source_branch, overwrite=True)
+                except NoSuchRevision:
+                    if source_branch.check_path() == NODE_FILE:
+                        self.to_transport.delete_tree(source_branch.get_branch_path())
+                        continue
+                    raise
                 if working_trees and not target_dir.has_workingtree():
                     target_dir.create_workingtree()
         finally:
