@@ -45,10 +45,10 @@ from bzrlib import (
     urlutils,
     )
 from bzrlib.errors import (
+    NoSuchId,
     NoSuchRevision,
     )
 from bzrlib.inventory import (
-    Inventory,
     InventoryDirectory,
     InventoryFile,
     InventoryLink,
@@ -56,6 +56,9 @@ from bzrlib.inventory import (
 from bzrlib.revision import (
     NULL_REVISION,
     )
+from bzrlib.revisiontree import (
+    RevisionTree,
+    )
 from bzrlib.repository import (
     InterRepository,
     )
@@ -123,7 +126,7 @@ def inventory_ancestors(inv, fileid, exceptions):
 
 def md5_strings(chunks):
     """Return the MD5sum of a list of chunks.
-    
+
     :param chunks: Chunks as strings
     :return: String with MD5 hex digest
     """
@@ -168,6 +171,8 @@ def editor_strip_prefix(editor, path):
 class PathStrippingDirectoryEditor(object):
     """Directory editor that strips a base from the paths."""
 
+    __slots__ = ('editor', 'path', 'actual')
+
     def __init__(self, editor, path, actual=None):
         self.editor = editor
         self.path = path
@@ -230,6 +235,8 @@ class PathStrippingDirectoryEditor(object):
 class PathStrippingEditor(object):
     """Editor that strips a base from the paths."""
 
+    __slots__ = ('actual', 'prefix')
+
     def __init__(self, actual, path):
         self.actual = actual
         self.prefix = path.strip("/")
@@ -268,6 +275,9 @@ class DeltaBuildEditor(object):
     """Implementation of the Subversion commit editor interface that
     converts Subversion to Bazaar semantics.
     """
+
+    __slots__ = ('revmeta', '_id_map', 'mapping')
+
     def __init__(self, revmeta, mapping):
         self.revmeta = revmeta
         self._id_map = None
@@ -289,6 +299,8 @@ class DeltaBuildEditor(object):
 
 class DirectoryBuildEditor(object):
 
+    __slots__ = ('editor', 'path')
+
     def __init__(self, editor, path):
         self.editor = editor
         self.path = path
@@ -365,6 +377,9 @@ class DirectoryBuildEditor(object):
 
 class FileBuildEditor(object):
 
+    __slots__ = ('path', 'editor', 'is_executable', 'is_special',
+                 'last_file_rev')
+
     def __init__(self, editor, path):
         self.path = path
         self.editor = editor
@@ -406,24 +421,26 @@ class FileBuildEditor(object):
 
 class DirectoryRevisionBuildEditor(DirectoryBuildEditor):
 
+    __slots__ = ('old_id', 'new_id', 'old_path', '_metadata_changed',
+                 '_renew_fileids', 'new_ie')
+
     def __init__(self, editor, old_path, path, old_id, new_id,
-            parent_file_id, parent_revids=[], renew_fileids=None):
+            parent_file_id, renew_fileids=None):
         super(DirectoryRevisionBuildEditor, self).__init__(editor, path)
         assert isinstance(new_id, str)
         self.old_id = old_id
         self.new_id = new_id
         self.old_path = old_path
-        self.parent_revids = parent_revids
         self._metadata_changed = False
         self._renew_fileids = renew_fileids
         self.new_ie = InventoryDirectory(self.new_id, urlutils.basename(self.path), parent_file_id)
-        if self.editor.old_inventory.has_id(self.new_id):
-            self.new_ie.revision = self.editor.old_inventory[self.new_id].revision
+        if self.editor.base_tree.has_id(self.new_id):
+            self.new_ie.revision = self.editor.base_tree.inventory[self.new_id].revision
 
     def _delete_entry(self, path, revnum):
         self.editor._explicitly_deleted.add(path)
         def rec_del(ie):
-            p = self.editor.old_inventory.id2path(ie.file_id)
+            p = self.editor.base_tree.inventory.id2path(ie.file_id)
             if p in self.editor._deleted:
                 return
             self.editor._deleted.add(p)
@@ -433,20 +450,19 @@ class DirectoryRevisionBuildEditor(DirectoryBuildEditor):
                 return
             for c in ie.children.values():
                 rec_del(c)
-        rec_del(self.editor.old_inventory[self.editor._get_old_id(self.old_id, path)])
+        rec_del(self.editor.base_tree.inventory[self.editor._get_old_id(self.old_id, path)])
 
     def _close(self):
-        if (not self.editor.old_inventory.has_id(self.new_id) or
+        if (not self.editor.base_tree.has_id(self.new_id) or
             (self._metadata_changed and self.path != u"") or
-            self.new_ie != self.editor.old_inventory[self.new_id] or
+            self.new_ie != self.editor.base_tree.inventory[self.new_id] or
             self.old_path != self.path or
             self.editor._get_text_revision(self.path) is not None):
             assert self.editor.revid is not None
 
-            self.new_ie.revision = (self.editor._get_text_revision(self.path) 
+            self.new_ie.revision = (self.editor._get_text_revision(self.path)
                                     or self.editor.revid)
-            text_parents = (self.editor._get_text_parents(self.path) or 
-                            self.parent_revids)
+            text_parents = self.editor._get_text_parents(self.new_id)
             self.editor.texts.insert_record_stream([
                 ChunkedContentFactory(
                 (self.new_id, self.new_ie.revision),
@@ -458,7 +474,7 @@ class DirectoryRevisionBuildEditor(DirectoryBuildEditor):
             # A bit expensive (O(d)), but this should be very rare
             delta_new_paths = set([e[1] for e in self.editor._inv_delta if e[1] is not None])
             exceptions = delta_new_paths.union(self.editor._explicitly_deleted)
-            for path in inventory_ancestors(self.editor.old_inventory, self._renew_fileids, exceptions):
+            for path in inventory_ancestors(self.editor.base_tree.inventory, self._renew_fileids, exceptions):
                 if isinstance(path, str):
                     path = path.decode("utf-8")
                 self.editor._renew_fileid(path)
@@ -469,13 +485,13 @@ class DirectoryRevisionBuildEditor(DirectoryBuildEditor):
     def _add_directory(self, path, copyfrom_path=None, copyfrom_revnum=-1):
         file_id = self.editor._get_new_id(path)
 
-        if self.editor.old_inventory.has_id(file_id):
+        if self.editor.base_tree.has_id(file_id):
             # This directory was moved here from somewhere else, but the
             # other location hasn't been removed yet.
             if copyfrom_path is None:
-                old_path = self.editor.old_inventory.id2path(file_id)
+                old_path = self.editor.base_tree.id2path(file_id)
             else:
-                assert copyfrom_path == self.editor.old_inventory.id2path(file_id)
+                assert copyfrom_path == self.editor.base_tree.id2path(file_id)
                 old_path = copyfrom_path
             old_file_id = file_id
         else:
@@ -487,32 +503,30 @@ class DirectoryRevisionBuildEditor(DirectoryBuildEditor):
 
     def _open_directory(self, path, base_revnum):
         base_file_id = self.editor._get_old_id(self.old_id, path)
-        base_revid = self.editor.old_inventory[base_file_id].revision
+        base_revid = self.editor.base_tree.inventory[base_file_id].revision
         file_id = self.editor._get_existing_id(self.old_id, self.new_id, path)
         if file_id == base_file_id:
-            file_parents = [base_revid]
             old_path = path
             renew_fileids = None
         else:
             old_path = None
-            file_parents = []
             self._delete_entry(path, base_revnum)
             # If a directory is replaced by a copy of itself, we need
             # to make sure all children get readded with a new file id
             renew_fileids = base_file_id
         return DirectoryRevisionBuildEditor(self.editor, old_path, path,
-            base_file_id, file_id, self.new_id, file_parents,
+            base_file_id, file_id, self.new_id,
             renew_fileids=renew_fileids)
 
     def _add_file(self, path, copyfrom_path=None, copyfrom_revnum=-1):
         file_id = self.editor._get_new_id(path)
-        if self.editor.old_inventory.has_id(file_id):
+        if self.editor.base_tree.has_id(file_id):
             # This file was moved here from somewhere else, but the
             # other location hasn't been removed yet.
             if copyfrom_path is None:
-                old_path = self.editor.old_inventory.id2path(file_id)
+                old_path = self.editor.base_tree.inventory.id2path(file_id)
             else:
-                if copyfrom_path != self.editor.old_inventory.id2path(file_id):
+                if copyfrom_path != self.editor.base_tree.inventory.id2path(file_id):
                     raise AssertionError
                 # No need to rename if it's already in the right spot
                 old_path = copyfrom_path
@@ -529,19 +543,16 @@ class DirectoryRevisionBuildEditor(DirectoryBuildEditor):
     def _open_file(self, path, base_revnum):
         base_file_id = self.editor._get_old_id(self.old_id, path)
         file_id = self.editor._get_existing_id(self.old_id, self.new_id, path)
-        base_ie = self.editor.old_inventory[base_file_id]
+        base_ie = self.editor.base_tree.inventory[base_file_id]
         is_symlink = (base_ie.kind == 'symlink')
         if file_id == base_file_id:
-            file_parents = [base_ie.revision]
             old_path = path
         else:
             # Replace with historical version
             old_path = None
-            file_parents = []
             self._delete_entry(path, base_revnum)
         return FileRevisionBuildEditor(self.editor, old_path, path, file_id,
-                                       self.new_id, base_ie, file_parents,
-                                       is_symlink=is_symlink)
+            self.new_id, base_ie, is_symlink=is_symlink)
 
 
 def content_starts_with_link(cf):
@@ -557,14 +568,15 @@ def content_starts_with_link(cf):
 
 class FileRevisionBuildEditor(FileBuildEditor):
 
+    __slots__ = ('old_path', 'file_id', 'is_symlink', 'base_ie', 'base_chunks',
+                 'chunks', 'parent_file_id')
+
     def __init__(self, editor, old_path, path, file_id, parent_file_id,
-                 base_ie, file_parents=[], is_symlink=False):
+                 base_ie, is_symlink=False):
         super(FileRevisionBuildEditor, self).__init__(editor, path)
         self.old_path = old_path
         self.file_id = file_id
-        # This should be the *chunks* of the file
         self.is_symlink = is_symlink
-        self.file_parents = file_parents
         self.base_ie = base_ie
         if self.base_ie is None:
             self.base_chunks = []
@@ -604,9 +616,7 @@ class FileRevisionBuildEditor(FileBuildEditor):
                         self.editor.revmeta.revnum)
         text_revision = (self.editor._get_text_revision(self.path) or
                          self.editor.revid)
-        text_parents = self.editor._get_text_parents(self.path)
-        if text_parents is None:
-            text_parents = self.file_parents
+        text_parents = self.editor._get_text_parents(self.file_id)
         parent_keys = tuple([(self.file_id, revid) for revid in text_parents])
         file_key = (self.file_id, text_revision)
         cf = ChunkedContentFactory(file_key, parent_keys, text_sha1, chunks)
@@ -656,16 +666,17 @@ class RevisionBuildEditor(DeltaBuildEditor):
     """Implementation of the Subversion commit editor interface that builds a
     Bazaar revision.
     """
-    def __init__(self, source, target, revid, prev_inventory, revmeta, mapping,
+
+    def __init__(self, source, target, revid, parent_trees, revmeta, mapping,
                  text_cache):
         self.target = target
         self.source = source
         self.texts = target.texts
         self.revid = revid
         self._text_revids = None
-        self._text_parents = None
         self._text_cache = text_cache
-        self.old_inventory = prev_inventory
+        self.base_tree = parent_trees[0]
+        self.parent_trees = parent_trees
         self._inv_delta = []
         self._deleted = set()
         self._explicitly_deleted = set()
@@ -680,7 +691,7 @@ class RevisionBuildEditor(DeltaBuildEditor):
             last_revmeta = revmeta
         assert last_revmeta is not None and last_revmeta.revnum == revnum
         revid = last_revmeta.get_revision_id(mapping)
-        # TODO: Use InterRepository._get_inventory() for better performance,
+        # TODO: Use InterRepository._get_tree() for better performance,
         # as it does (some) caching ?
         inv = self.target.get_inventory(revid)
         file_id = inv.path2id(path)
@@ -695,21 +706,18 @@ class RevisionBuildEditor(DeltaBuildEditor):
 
     def _finish_commit(self):
         rev = self.revmeta.get_revision(self.mapping)
-        # Escaping the commit message is really the task of the serialiser
-        if getattr(self.target._serializer, "squashes_xml_invalid_characters", True):
-            from bzrlib.xml_serializer import escape_invalid_chars
-            rev.message, num_replaced = escape_invalid_chars(rev.message)
         try:
             basis_id = rev.parent_ids[0]
-            basis_inv = self.old_inventory
+            basis_inv = self.base_tree.inventory
         except IndexError:
             basis_id = NULL_REVISION
             basis_inv = None
         present_parent_ids = self.target.has_revisions(rev.parent_ids)
-        rev.inventory_sha1, self.inventory = self.target.add_inventory_by_delta(basis_id,
-                  self._inv_delta, rev.revision_id,
-                  tuple([r for r in rev.parent_ids if r in present_parent_ids]),
-                  basis_inv)
+        rev.inventory_sha1, self.inventory = \
+            self.target.add_inventory_by_delta(basis_id, self._inv_delta,
+            rev.revision_id,
+            tuple([r for r in rev.parent_ids if r in present_parent_ids]),
+            basis_inv)
         self.target.add_revision(self.revid, rev)
 
         # Only fetch signature if it's cheap
@@ -721,37 +729,34 @@ class RevisionBuildEditor(DeltaBuildEditor):
     def _open_root(self, base_revnum):
         assert self.revid is not None
 
-        if self.old_inventory.root is None:
+        if self.base_tree.inventory.root is None:
             # First time the root is set
             base_file_id = None
             file_id = self._get_new_id(u"")
-            file_parents = []
             renew_fileids = None
             old_path = None
         else:
             # Just inherit file id from previous
             base_file_id = self._get_old_id(None, u"")
-            base_revid = self.old_inventory[base_file_id].revision
+            base_revid = self.base_tree.inventory[base_file_id].revision
             file_id = self._get_existing_id(None, None, u"")
             if file_id == base_file_id:
-                file_parents = [base_revid]
                 renew_fileids = None
-                old_path = self.old_inventory.id2path(file_id)
+                old_path = self.base_tree.id2path(file_id)
             else:
                 old_path = None
-                file_parents = []
                 self._inv_delta.append((u"", None, base_file_id, None))
                 renew_fileids =  base_file_id
         assert isinstance(file_id, str)
 
         return DirectoryRevisionBuildEditor(self, old_path, u"", base_file_id,
-            file_id, None, file_parents, renew_fileids)
+            file_id, None, renew_fileids)
 
     def _renew_fileid(self, path):
         """'renew' the fileid of a path."""
         assert isinstance(path, unicode)
-        old_file_id = self.old_inventory.path2id(path)
-        old_ie = self.old_inventory[old_file_id]
+        old_file_id = self.base_tree.path2id(path)
+        old_ie = self.base_tree.inventory[old_file_id]
         new_ie = old_ie.copy()
         new_ie.file_id = self._get_new_id(path)
         new_ie.parent_id = self._get_new_id(urlutils.split(path)[0])
@@ -786,20 +791,20 @@ class RevisionBuildEditor(DeltaBuildEditor):
         assert (isinstance(parent_id, str) or
                 (parent_id is None and old_path == ""))
         if old_path == "":
-            return self.old_inventory.root.file_id
+            return self.base_tree.inventory.root.file_id
         basename = urlutils.basename(old_path)
-        parent_id_basename_index = getattr(self.old_inventory, "parent_id_basename_to_file_id", None)
+        parent_id_basename_index = getattr(self.base_tree.inventory, "parent_id_basename_to_file_id", None)
         if parent_id_basename_index is None:
             try:
-                return self.old_inventory[parent_id].children[basename].file_id
+                return self.base_tree.inventory[parent_id].children[basename].file_id
             except KeyError:
-                raise FileIdMapIncomplete(basename, self.old_inventory.id2path(parent_id), self.revmeta)
+                raise FileIdMapIncomplete(basename, self.base_tree.inventory.id2path(parent_id), self.revmeta)
         else:
             ret = parent_id_basename_index.iteritems([(parent_id or '', basename.encode("utf-8"))])
             try:
                 return ret.next()[1]
             except IndexError:
-                raise FileIdMapIncomplete(basename, self.old_inventory.id2path(parent_id), self.revmeta)
+                raise FileIdMapIncomplete(basename, self.base_tree.inventory.id2path(parent_id), self.revmeta)
 
     def _get_existing_id(self, old_parent_id, new_parent_id, path):
         assert isinstance(path, unicode)
@@ -829,15 +834,24 @@ class RevisionBuildEditor(DeltaBuildEditor):
             self._text_revids = self.revmeta.get_text_revisions(self.mapping)
         return self._text_revids.get(path)
 
-    def _get_text_parents(self, path):
-        assert isinstance(path, unicode)
-        if self._text_parents is None:
-            self._text_parents = self.revmeta.get_text_parents(self.mapping)
-        return self._text_parents.get(path)
+    def _get_text_parents(self, file_id):
+        assert isinstance(file_id, str)
+        ret = []
+        for tree in self.parent_trees:
+            try:
+                revision = tree.inventory[file_id].revision
+            except NoSuchId:
+                pass
+            else:
+                if not revision in ret:
+                    ret.append(revision)
+        return ret
 
 
 class FileTreeDeltaBuildEditor(FileBuildEditor):
 
+    __slots__ = ('copyfrom_path', 'base_checksum', 'change_kind')
+
     def __init__(self, editor, path, copyfrom_path, kind):
         super(FileTreeDeltaBuildEditor, self).__init__(editor, path)
         self.copyfrom_path = copyfrom_path
@@ -856,12 +870,16 @@ class FileTreeDeltaBuildEditor(FileBuildEditor):
             entry_kind = 'file'
         if self.change_kind == 'add':
             if self.copyfrom_path is not None and self._get_map_id(self.path) is not None:
-                self.editor.delta.renamed.append((self.copyfrom_path, self.path, self.editor._get_new_id(self.path), entry_kind,
-                                                 text_changed, metadata_changed))
+                self.editor.delta.renamed.append((self.copyfrom_path, self.path,
+                    self.editor._get_new_id(self.path), entry_kind,
+                    text_changed, metadata_changed))
             else:
-                self.editor.delta.added.append((self.path, self.editor._get_new_id(self.path), entry_kind))
+                self.editor.delta.added.append((self.path,
+                    self.editor._get_new_id(self.path), entry_kind))
         else:
-            self.editor.delta.modified.append((self.path, self.editor._get_new_id(self.path), entry_kind, text_changed, metadata_changed))
+            self.editor.delta.modified.append((self.path,
+                self.editor._get_new_id(self.path), entry_kind, text_changed,
+                metadata_changed))
 
     def _apply_textdelta(self, base_checksum=None):
         self.base_checksum = None
@@ -870,6 +888,8 @@ class FileTreeDeltaBuildEditor(FileBuildEditor):
 
 class DirectoryTreeDeltaBuildEditor(DirectoryBuildEditor):
 
+    __slots__ = ()
+
     def _close(self):
         pass
 
@@ -898,6 +918,7 @@ class TreeDeltaBuildEditor(DeltaBuildEditor):
     """Implementation of the Subversion commit editor interface that builds a
     Bazaar TreeDelta.
     """
+
     def __init__(self, revmeta, mapping, newfileidmap, oldfileidmap):
         super(TreeDeltaBuildEditor, self).__init__(revmeta, mapping)
         self._parent_idmap = oldfileidmap
@@ -934,14 +955,15 @@ def report_inventory_contents(reporter, revnum, start_empty):
     except:
         reporter.abort()
         raise
-    reporter.finish()
+    else:
+        reporter.finish()
 
 
 class FetchRevisionFinder(object):
     """Simple object that can gather a list of revmeta, mapping tuples
     to fetch."""
 
-    def __init__(self, source, target, target_is_empty):
+    def __init__(self, source, target, target_is_empty=False):
         self.source = source
         self.target = target
         self.target_is_empty = target_is_empty
@@ -950,9 +972,11 @@ class FetchRevisionFinder(object):
         self.extra = list()
         self._check_present_interval = 1
 
-    def get_missing(self):
+    def get_missing(self, limit=None):
         """Return the revisions that should be fetched, children before parents.
         """
+        if limit is not None:
+            return self.needed[:limit]
         return self.needed
 
     def check_revmetas(self, revmetas):
@@ -1032,7 +1056,8 @@ class FetchRevisionFinder(object):
         # TODO: Do binary search to find first revision to fetch if
         # fetch_ghosts=False ?
         needs_checking = []
-        for revmeta, mapping in self.source._iter_reverse_revmeta_mapping_history(branch_path, revnum, to_revnum=0, mapping=mapping):
+        for revmeta, mapping in self.source._iter_reverse_revmeta_mapping_history(
+            branch_path, revnum, to_revnum=0, mapping=mapping):
             if pb:
                 pb.update("determining revisions to fetch",
                           revnum-revmeta.revnum, revnum)
@@ -1095,26 +1120,28 @@ class InterFromSvnRepository(InterRepository):
         self._text_cache = lru_cache.LRUSizeCache(TEXT_CACHE_SIZE,
                                                   compute_size=chunks_to_size)
 
-        self._use_replay_range = self.source.transport.has_capability("partial-replay") and False
-        self._use_replay = self.source.transport.has_capability("partial-replay") and False
+        self._use_replay_range = self.source.transport.has_capability(
+            "partial-replay") and False
+        self._use_replay = self.source.transport.has_capability(
+            "partial-replay") and False
 
     def copy_content(self, revision_id=None, pb=None):
         """See InterRepository.copy_content."""
         self.fetch(revision_id, pb, find_ghosts=False)
 
-    def _get_inventory(self, revid):
+    def _get_tree(self, revid):
         """Retrieve an inventory, optionally using a inventory previously
         cached.
 
         :param revid: Revision id to use.
         """
-        if revid == NULL_REVISION:
-            return Inventory(root_id=None)
-        if self._prev_inv is not None and self._prev_inv.revision_id == revid:
-            return self._prev_inv
+        if self._prev_tree is not None and self._prev_tree.get_revision_id() == revid:
+            return self._prev_tree
         if "check" in debug.debug_flags:
+            # This uses 'assert' rather than raising AssertionError
+            # intentionally, it's a fairly expensive check.
             assert self.target.has_revision(revid)
-        return self.target.get_inventory(revid)
+        return self.target.revision_tree(revid)
 
     def _inconsistent_lhs_parent(self, revid, stored_lhs_parent_revid,
             found_lhs_parent_revid):
@@ -1124,17 +1151,32 @@ class InterFromSvnRepository(InterRepository):
             "%s.", revid, stored_lhs_parent_revid, found_lhs_parent_revid)
         self.fetch(found_lhs_parent_revid)
 
+    def _get_parent_trees(self, revmeta, mapping):
+        parent_revids = revmeta.get_parent_ids(mapping)
+        if not parent_revids:
+            parent_revids = (NULL_REVISION,)
+        # We always need the base inventory for the first parent
+        parent_trees = [self.target.revision_tree(parent_revids[0])]
+        for revid in parent_revids:
+            try:
+                parent_trees.append(self.target.revision_tree(revid))
+            except NoSuchRevision:
+                pass # Ghost
+        return parent_trees
+
     def _get_editor(self, revmeta, mapping):
         revid = revmeta.get_revision_id(mapping)
         assert revid is not None
         try:
             return RevisionBuildEditor(self.source, self.target, revid,
-                self._get_inventory(revmeta.get_lhs_parent_revid(mapping)),
+                self._get_parent_trees(revmeta, mapping),
                 revmeta, mapping, self._text_cache)
         except NoSuchRevision:
             lhs_parent_revmeta = revmeta.get_lhs_parent_revmeta(mapping)
-            expected_lhs_parent_revid = revmeta.get_implicit_lhs_parent_revid(mapping)
-            if revmeta.get_stored_lhs_parent_revid(mapping) not in (None, expected_lhs_parent_revid):
+            expected_lhs_parent_revid = revmeta.get_implicit_lhs_parent_revid(
+                mapping)
+            if revmeta.get_stored_lhs_parent_revid(mapping) not in (
+                None, expected_lhs_parent_revid):
                 self._inconsistent_lhs_parent(revmeta.get_revision_id(mapping),
                     revmeta.get_stored_lhs_parent_revid(mapping),
                     expected_lhs_parent_revid)
@@ -1197,7 +1239,7 @@ class InterFromSvnRepository(InterRepository):
         :param pb: Optional progress bar.
         """
         accidental_file_revs = set()
-        self._prev_inv = None
+        self._prev_tree = None
         batch_size = 100
         total = len(revs)
         pack_hints = []
@@ -1234,8 +1276,8 @@ class InterFromSvnRepository(InterRepository):
                     except:
                         editor.abort()
                         raise
-                    self._prev_inv = editor.inventory
-                    assert self._prev_inv.revision_id == revid
+                    self._prev_tree = RevisionTree(self.target,
+                        editor.inventory, revid)
             except:
                 self.target.abort_write_group()
                 raise
@@ -1246,12 +1288,50 @@ class InterFromSvnRepository(InterRepository):
         return pack_hints
 
     def _fetch_revisions(self, needed, pb):
+        """Fetch a specified set of revisions.
+
+        :param needed: Sequence of revision ids to fetch, topo-sorted
+        :param pb: Progress bar to use for reporting progress
+        :return: Pack hint
+        """
         if self._use_replay_range:
             return self._fetch_revisions_chunks(needed, pb)
         else:
             return self._fetch_revisions_nochunks(needed, pb,
                 use_replay=self._use_replay)
 
+    def _get_needed(self, revision_id=None, fetch_spec=None, project=None,
+                    target_is_empty=False, pb=None, find_ghosts=False):
+        """Find the set of revisions that is missing.
+
+        :note: revision_id and fetch_spec are mutually exclusive
+
+        :param revision_id: Optional target revision id
+        :param fetch_spec: Specifier describing the revisions to fetch
+        :param project: Project name as used by the repository layout, if applicable
+        :param target_is_empty: Whether the target is empty
+            (aka: should has_revision be called)
+        :param pb: Optional progress bar to use.
+        :param find_ghosts: Whether to find ghosts
+        :return: Iterable over missing revision ids
+        """
+        revisionfinder = FetchRevisionFinder(self.source, self.target,
+                                             target_is_empty)
+        if revision_id is not None:
+            foreign_revid, mapping = self.source.lookup_bzr_revision_id(
+                revision_id, project=project)
+            revisionfinder.find_until(foreign_revid, mapping,
+                                      find_ghosts=find_ghosts, pb=pb)
+        elif fetch_spec is not None:
+            for head in fetch_spec.heads:
+                foreign_revid, mapping = self.source.lookup_bzr_revision_id(
+                    head, project=project)
+                revisionfinder.find_until(foreign_revid, mapping,
+                    find_ghosts=find_ghosts, pb=pb)
+        else:
+            revisionfinder.find_all(self.source.get_mapping(), pb=pb)
+        return revisionfinder.get_missing()
+
     def fetch(self, revision_id=None, pb=None, find_ghosts=False,
               needed=None, mapping=None, project=None, fetch_spec=None):
         """Fetch revisions. """
@@ -1267,29 +1347,16 @@ class InterFromSvnRepository(InterRepository):
         # or self.target.add_inventory() each time
         self.target.lock_write()
         try:
-            nested_pb = ui.ui_factory.nested_progress_bar()
-            try:
-                # FIXME: Specify target_is_empt
-                target_is_empty = False
-                revisionfinder = FetchRevisionFinder(self.source, self.target,
-                                                     target_is_empty)
-                if needed is None:
-                    if revision_id is not None:
-                        foreign_revid, mapping = self.source.lookup_bzr_revision_id(revision_id, project=project)
-                        revisionfinder.find_until(foreign_revid,
-                            mapping, find_ghosts=find_ghosts,
-                            pb=nested_pb)
-                    elif fetch_spec is not None:
-                        for head in fetch_spec.heads:
-                            foreign_revid, mapping = self.source.lookup_bzr_revision_id(head, project=project)
-                            revisionfinder.find_until(foreign_revid,
-                                mapping, find_ghosts=find_ghosts,
-                                pb=nested_pb)
-                    else:
-                        revisionfinder.find_all(self.source.get_mapping(), pb=nested_pb)
-                    needed = revisionfinder.get_missing()
-            finally:
-                nested_pb.finished()
+            if needed is None:
+                nested_pb = ui.ui_factory.nested_progress_bar()
+                try:
+                    # FIXME: Specify target_is_empty
+                    needed = self._get_needed(target_is_empty=False,
+                        revision_id=revision_id, fetch_spec=fetch_spec,
+                        find_ghosts=find_ghosts, project=project,
+                        pb=nested_pb)
+                finally:
+                    nested_pb.finished()
 
             if len(needed) == 0:
                 # Nothing to fetch
@@ -1305,18 +1372,18 @@ class InterFromSvnRepository(InterRepository):
                 nested_pb = None
             try:
                 pack_hint = self._fetch_revisions(needed, pb)
-                if pack_hint is not None and self.target._format.pack_compresses:
+                if (pack_hint is not None and
+                    self.target._format.pack_compresses):
                     self.target.pack(hint=pack_hint)
             finally:
                 if nested_pb is not None:
                     nested_pb.finished()
-            if (revision_id is not None and
-                not self.target.has_revision(revision_id)):
-                # Apparently we could find the revision but it wasn't
-                # imported using the same mapping or perhaps
-                # revision_id was a mapped revision id and the revision
-                # itself was roundtripped.
-                raise NoSuchRevision(self.source, revision_id)
+            # Double check that we can actually find the revision that we
+            # attempted to fetch.
+            # This uses 'assert' rather than raising AssertionError
+            # intentionally, it's a fairly expensive check.
+            assert revision_id is None or self.target.has_revision(
+                revision_id)
         finally:
             self.target.unlock()
 
@@ -1327,7 +1394,6 @@ class InterFromSvnRepository(InterRepository):
         :param pb: Optional progress bar
         """
         self._prev_inv = None
-        currange = None
         activeranges = defaultdict(list)
         pb = ui.ui_factory.nested_progress_bar()
         try:
