@@ -22,14 +22,13 @@ subvertpy_minimum_version = (0, 6, 1)
 # versions ending in 'exp' mean experimental mappings
 # versions ending in 'dev' mean development version
 # versions ending in 'final' mean release (well tested, etc)
-bzr_plugin_version = (1, 0, 2, 'final', 0)
+bzr_plugin_version = (1, 0, 3, 'final', 0)
 
 bzr_commands = ["svn-import", "svn-layout"]
 
 bzr_transports = ["svn://", "svn+"]
 
-bzr_compatible_versions = [(1, x, 0) for x in [16, 17, 18]] + \
-                          [(2, x, 0) for x in [0, 1]]
+bzr_compatible_versions = [(2, x, 0) for x in [0, 1, 2]]
 
 bzr_minimum_version = bzr_compatible_versions[0]
 
