@@ -28,8 +28,6 @@ from subvertpy import (
     )
 
 from bzrlib import (
-    debug,
-    trace,
     urlutils,
     )
 from bzrlib.errors import (
@@ -49,7 +47,9 @@ def keyword_date(revid, rev, relpath, revmeta):
     """last changed date"""
     if revmeta is not None:
         return revmeta.get_revprops().get(properties.PROP_REVISION_DATE, "")
-    return properties.time_to_cstring(1000000*rev.timestamp)
+    if rev is not None:
+        return properties.time_to_cstring(1000000*rev.timestamp)
+    return None
 
 
 def keyword_rev(revid, rev, relpath, revmeta):
@@ -60,6 +60,9 @@ def keyword_rev(revid, rev, relpath, revmeta):
     if revmeta is not None:
         return str(revmeta.revnum)
 
+    if revid is None:
+        return None
+
     # Revision was once imported from a foreign repository
     try:
         foreign_revid, mapping = mapping_registry.parse_revision_id(revid)
@@ -76,7 +79,9 @@ def keyword_author(revid, rev, relpath, revmeta):
     """author of the last commit."""
     if revmeta is not None:
         return revmeta.get_revprops().get(properties.PROP_REVISION_AUTHOR, "")
-    return rev.committer
+    if rev is not None:
+        return rev.committer.encode("utf-8")
+    return None
 
 
 def keyword_id(*args):
@@ -135,27 +140,28 @@ def expand_keywords(s, allowed_keywords, context=None, encoder=None):
         if not match:
             break
         result += rest[:match.start()]
+        original_expansion = match.group(0)
         keyword = match.group(1)
         if not keyword in allowed_keywords:
             # Unknown expansion - leave as is
-            result += match.group(0)
+            result += original_expansion
             rest = rest[match.end():]
             continue
-        try:
-            expansion = keywords[keyword](context.revision_id(),
-                context.revision(), context.relpath(),
-                getattr(context.revision(), "svn_meta", None))
-        except AttributeError, err:
-            if 'error' in debug.debug_flags:
-                trace.note("error evaluating %s for keyword %s: %s",
-                    expansion, keyword, err)
-            expansion = "(evaluation error)"
-        if '$' in expansion:
-            # Expansion is not safe to be collapsed later
-            expansion = "(value unsafe to expand)"
-        if encoder is not None:
-            expansion = encoder(expansion)
-        result += "$%s: %s $" % (keyword, expansion)
+        expansion = keywords[keyword](context.revision_id(),
+            context.revision(), context.relpath().encode("utf-8"),
+            getattr(context.revision(), "svn_meta", None))
+        if expansion is not None and type(expansion) is not str:
+            raise AssertionError("Expansion string not plain: %r" % expansion)
+        if expansion is not None:
+            if '$' in expansion:
+                # Expansion is not safe to be collapsed later
+                expansion = "(value unsafe to expand)"
+            if encoder is not None:
+                expansion = encoder(expansion)
+            expanded = "$%s: %s $" % (keyword, expansion)
+        else:
+            expanded = "$%s$" % keyword
+        result += expanded
         rest = rest[match.end():]
     return result + rest
 
@@ -202,10 +208,10 @@ class SubversionKeywordContentFilter(ContentFilter):
 def create_svn_keywords_filter(value):
     if not value:
         return
-    keywords = value.split(" ")
-    for k in keywords:
+    kws = value.split(" ")
+    for k in kws:
         if not k in keywords:
             raise BzrError("Unknown svn keyword %s" % k)
-    if keywords == []:
+    if kws == []:
         return []
-    return [SubversionKeywordContentFilter(keywords)]
+    return [SubversionKeywordContentFilter(kws)]
