@@ -39,59 +39,110 @@ from bzrlib.plugins.svn.util import (
     lazy_dict,
     )
 
+from subvertpy import NODE_UNKNOWN
+
 
 # Maximum number of extra revisions to fetch in caching logwalker
 MAX_OVERHEAD_FETCH = 1000
 
-def iter_changes(prefixes, from_revnum, to_revnum, get_revision_paths,
+def iter_all_changes(from_revnum, to_revnum, get_revision_paths, 
     revprop_list, limit=0):
-    ascending = (to_revnum > from_revnum)
-
     revnum = from_revnum
-
-    if prefixes is None:
-        path = ""
-    else:
-        assert len(prefixes) == 1
-        path = prefixes[0].strip("/")
-
-    assert from_revnum >= to_revnum or path == "", \
-            "path: %s, %d >= %d" % (path, from_revnum, to_revnum)
-
+    ascending = (to_revnum > from_revnum)
     i = 0
-
     while ((not ascending and revnum >= to_revnum) or
            (ascending and revnum <= to_revnum)):
-        if not (revnum > 0 or path == ""):
-            raise AssertionError("Inconsistent path,revnum: %r,%r" % (revnum, path))
         revpaths = get_revision_paths(revnum)
 
-        if ascending:
-            next = (path, revnum+1)
-        else:
-            next = changes.find_prev_location(revpaths, path, revnum)
+        # Report this revision if any affected paths are changed
+        yield (revpaths, revnum, revprop_list(revnum))
+        i += 1
+        if limit != 0 and i == limit:
+            break
 
-        if path == "" or changes.changes_path(revpaths, path, True):
-            assert isinstance(revnum, int)
+        if ascending:
+            revnum += 1
+        else:
+            revnum -= 1
+
+
+def iter_changes(prefixes, from_revnum, to_revnum, get_revision_paths,
+    revprop_list, limit=0):
+    """Iter changes.
+
+    :param prefix: Sequence of paths
+    :param from_revnum: Start revision number
+    :param to_revnum: End revision number
+    :param get_revision_paths: Callback to retrieve the paths
+        for a particular revision
+    :param revprop_list: Callback to retrieve the revision properties
+        for a particular revision
+    :param limit: Maximum number of revisions to yield, 0 for all
+    :return: Iterator over (revpaths, revnum, revprops)
+    """
+    revnum = from_revnum
+
+    if prefixes in (None, [""], []):
+        return iter_all_changes(from_revnum, to_revnum, get_revision_paths,
+                revprop_list, limit)
+    else:
+        return iter_prefixes_changes(prefixes, from_revnum, to_revnum,
+            get_revision_paths, revprop_list, limit)
+
+
+def iter_prefixes_changes(prefixes, from_revnum, to_revnum, 
+    get_revision_paths, revprop_list, limit=0):
+    prefixes = [p.strip("/") for p in prefixes]
+
+    assert from_revnum >= to_revnum, "path: %r, %d >= %d" % (
+            prefixes, from_revnum, to_revnum)
+
+    revnum = from_revnum
+    todo_prefixes = { revnum: set(prefixes) }
+
+    i = 0
+    while revnum >= to_revnum:
+        prefixes = todo_prefixes.pop(revnum)
+        if not (revnum > 0):
+            raise AssertionError("Inconsistent revnum, prefixes: %r,%r" % (revnum, prefixes))
+        revpaths = get_revision_paths(revnum)
+
+        # Report this revision if any affected paths are changed
+        if any(changes.changes_path(revpaths, prefix, True) for prefix in prefixes):
+            assert type(revnum) is int
             yield (revpaths, revnum, revprop_list(revnum))
             i += 1
             if limit != 0 and i == limit:
                 break
 
-        if next is None:
-            break
+        next = {}
+        # Find the location of each prefix for the next iteration
+        for prefix in prefixes:
+            assert type(prefix) is str, "%r" % prefix
+            try:
+                (p, r) = changes.find_prev_location(revpaths, prefix,
+                        revnum)
+            except TypeError:
+                pass # didn't exist here
+            else:
+                assert r < revnum
+                todo_prefixes.setdefault(r, set()).add(p)
 
-        assert (ascending and next[1] > revnum) or \
-               (not ascending and next[1] < revnum)
-        (path, revnum) = next
-        assert isinstance(path, str)
-        assert isinstance(revnum, int)
+        if todo_prefixes == {}:
+            break
+        revnum = max(todo_prefixes)
 
 
 class LogCache(object):
     """Log browser cache. """
 
     def find_latest_change(self, path, revnum):
+        """Find the last revision in which a particular path
+        was changed.
+
+        :param path: Path to check
+        :param revnum: Revision in which to check
+        """
         raise NotImplementedError(self.find_latest_change)
 
     def get_revision_paths(self, revnum):
@@ -175,7 +226,6 @@ class CachingLogWalker(object):
         assert from_revnum >= 0 and to_revnum >= 0, "%r -> %r" % (from_revnum, to_revnum)
         self.mutter("iter changes %r->%r (%r)", from_revnum, to_revnum, prefixes)
         self._fetch_revisions(max(from_revnum, to_revnum), pb=pb)
-
         return iter(iter_changes(prefixes, from_revnum, to_revnum,
             self.get_revision_paths, self.revprop_list, limit))
 
@@ -231,7 +281,8 @@ class CachingLogWalker(object):
             todo_revprops = ["svn:author", "svn:log", "svn:date"]
 
         def rcvr(orig_paths, revision, revprops, has_children=None):
-            nested_pb.update('fetching svn revision info', to_revnum - revision, to_revnum)
+            nested_pb.update('fetching svn revision info',
+                             to_revnum - revision, to_revnum)
             self.cache.insert_paths(revision, orig_paths)
             self.cache.insert_revprops(revision, revprops,
                                        todo_revprops is None)
@@ -273,16 +324,25 @@ class CachingLogWalker(object):
 
 
 def strip_slashes(changed_paths):
+    """Strip the leading and trailing slashes in paths.
+
+    :param changed_paths: Changed paths dictionary
+    :return: Update paths dictionary
+    """
     if changed_paths is None:
         return {}
-    assert isinstance(changed_paths, dict)
+    assert type(changed_paths) is dict
     revpaths = {}
-    for k, (action, copyfrom_path, copyfrom_rev) in changed_paths.iteritems():
-        if copyfrom_path is None:
+    for k, v in changed_paths.iteritems():
+        try:
+            kind = v[3]
+        except IndexError:
+            kind = NODE_UNKNOWN
+        if v[1] is None:
             copyfrom_path = None
         else:
-            copyfrom_path = copyfrom_path.strip("/")
-        revpaths[k.strip("/")] = (action, copyfrom_path, copyfrom_rev)
+            copyfrom_path = v[1].strip("/")
+        revpaths[k.strip("/")] = (v[0], copyfrom_path, v[2], kind)
     return revpaths
 
 
@@ -309,7 +369,8 @@ class LogWalker(object):
         assert isinstance(revnum, int) and revnum >= 0
 
         try:
-            return self._transport.iter_log([path], revnum, 0, 2, True, False, False, []).next()[1]
+            return self._transport.iter_log([path], revnum, 0, 2, True, False,
+                    False, []).next()[1]
         except subvertpy.SubversionException, (_, num):
             if num == subvertpy.ERR_FS_NO_SUCH_REVISION:
                 raise NoSuchRevision(branch=self,
@@ -332,13 +393,13 @@ class LogWalker(object):
         """
         assert from_revnum >= 0 and to_revnum >= 0
 
-        try:
-            # Subversion 1.4 clients and servers can only deliver a limited set of revprops
-            if self._transport.has_capability("log-revprops"):
-                todo_revprops = None
-            else:
-                todo_revprops = ["svn:author", "svn:log", "svn:date"]
+        # Subversion 1.4 clients and servers can only deliver a limited set of revprops
+        if self._transport.has_capability("log-revprops"):
+            todo_revprops = None
+        else:
+            todo_revprops = ["svn:author", "svn:log", "svn:date"]
 
+        try:
             iterator = self._transport.iter_log(prefixes, from_revnum,
                 to_revnum, limit, True, False, False, revprops=todo_revprops)
 
@@ -387,7 +448,8 @@ class DictBasedLogWalker(object):
         self.paths = paths
         self.revprops = revprops
 
-    def iter_changes(self, prefixes, from_revnum, to_revnum=0, limit=0, pb=None):
+    def iter_changes(self, prefixes, from_revnum, to_revnum=0, limit=0,
+            pb=None):
         return iter(iter_changes(prefixes, from_revnum, to_revnum,
             self.get_revision_paths, self.revprop_list, limit))
 
