@@ -49,7 +49,6 @@ SVN_PROP_BZR_FILEIDS = 'bzr:file-ids'
 SVN_PROP_BZR_REVISION_INFO = 'bzr:revision-info'
 SVN_PROP_BZR_REVISION_ID = 'bzr:revision-id:'
 SVN_PROP_BZR_TEXT_REVISIONS = 'bzr:text-revisions'
-SVN_PROP_BZR_TEXT_PARENTS = 'bzr:text-parents'
 SVN_PROP_BZR_LOG = 'bzr:log'
 SVN_PROP_BZR_REQUIRED_FEATURES = 'bzr:required-features'
 SVN_PROP_BZR_HIDDEN = 'bzr:hidden'
@@ -67,7 +66,6 @@ SVN_REVPROP_BZR_ROOT = 'bzr:root'
 SVN_REVPROP_BZR_SIGNATURE = 'bzr:gpg-signature'
 SVN_REVPROP_BZR_TIMESTAMP = 'bzr:timestamp'
 SVN_REVPROP_BZR_LOG = 'bzr:log'
-SVN_REVPROP_BZR_TEXT_PARENTS = 'bzr:text-parents'
 SVN_REVPROP_BZR_TEXT_REVISIONS = 'bzr:text-revisions'
 SVN_REVPROP_BZR_REQUIRED_FEATURES = 'bzr:required-features'
 SVN_REVPROP_BZR_BASE_REVISION = 'bzr:base-revision'
@@ -194,11 +192,8 @@ def parse_svn_dateprop(date):
 
 def parse_svn_log(log):
     if log is None:
-        return ""
-    try:
-        return log.decode("utf-8")
-    except UnicodeDecodeError:
-        return log
+        return u""
+    return log.decode("utf-8", "replace")
 
 
 def parse_svn_revprops(svn_revprops, rev):
@@ -206,9 +201,11 @@ def parse_svn_revprops(svn_revprops, rev):
     if rev.committer is None:
         rev.committer = u""
     rev.message = parse_svn_log(svn_revprops.get(properties.PROP_REVISION_LOG))
+    assert type(rev.message) is unicode
 
     assert svn_revprops.has_key(properties.PROP_REVISION_DATE)
-    (rev.timestamp, rev.timezone) = parse_svn_dateprop(svn_revprops[properties.PROP_REVISION_DATE])
+    (rev.timestamp, rev.timezone) = parse_svn_dateprop(
+            svn_revprops[properties.PROP_REVISION_DATE])
     rev.properties = {}
 
 
@@ -305,7 +302,8 @@ def parse_bzr_svn_revprops(props, rev):
         changed = True
 
     if props.has_key(SVN_REVPROP_BZR_LOG):
-        rev.message = props[SVN_REVPROP_BZR_LOG]
+        rev.message = props[SVN_REVPROP_BZR_LOG].decode("utf-8")
+        assert type(rev.message) is unicode
         changed = True
 
     for name, value in props.iteritems():
@@ -511,40 +509,10 @@ class BzrSvnMapping(foreign.VcsMapping):
         """
         raise NotImplementedError(self.export_fileid_map_fileprops)
 
-    def import_text_parents_revprops(self, revprops):
-        """Obtain a text parent map from properties.
-
-        :param revprops: Subversion revision properties.
-        """
-        raise NotImplementedError(self.import_text_parents_revprops)
-
-    def import_text_parents_fileprops(self, fileprops):
-        """Obtain a text parent map from properties.
-
-        :param fileprops: File properties.
-        """
-        raise NotImplementedError(self.import_text_parents_fileprops)
-
-    def export_text_parents_revprops(self, text_parents, revprops):
-        """Store a text parent map.
-
-        :param text_parents: Text parent map
-        :param revprops: Revision properties
-        """
-        raise NotImplementedError(self.export_text_parents_revprops)
-
-    def export_text_parents_fileprops(self, text_parents, fileprops):
-        """Store a text parent map.
-
-        :param text_parents: Text parent map
-        :param fileprops: File properties
-        """
-        raise NotImplementedError(self.export_text_parents_fileprops)
-
     def export_text_revisions_revprops(self, text_revisions, revprops):
         """Store a text revisions map.
 
-        :param text_parents: Text revision map
+        :param text_revisions: Text revision map
         :param revprops: Revision properties
         """
         raise NotImplementedError(self.export_text_revisions_revprops)
@@ -552,7 +520,7 @@ class BzrSvnMapping(foreign.VcsMapping):
     def export_text_revisions_fileprops(self, text_revisions, fileprops):
         """Store a text revisions map.
 
-        :param text_parents: Text revision map
+        :param text_revisions: Text revision map
         :param fileprops: File properties
         """
         raise NotImplementedError(self.export_text_revisions_fileprops)
@@ -643,15 +611,6 @@ def generate_fileid_property(fileids):
     return "".join(["%s\t%s\n" % (urllib.quote(path.encode("utf-8")), fileids[path]) for path in sorted(fileids.keys())])
 
 
-def parse_text_parents_property(text):
-    ret = {}
-    for line in text.splitlines():
-        parts = line.split("\t")
-        entry = parts[0]
-        ret[urllib.unquote(entry).decode("utf-8")] = filter(lambda x: x != "", [osutils.safe_revision_id(parent_revid) for parent_revid in parts[1:]])
-    return ret
-
-
 def parse_text_revisions_property(text):
     ret = {}
     for line in text.splitlines():
@@ -660,21 +619,19 @@ def parse_text_revisions_property(text):
     return ret
 
 
-def generate_text_parents_property(text_parents):
-    return "".join(["%s\t%s\n" % (urllib.quote(path.encode("utf-8")), "\t".join(text_parents[path])) for path in sorted(text_parents.keys())])
-
-
 def generate_text_revisions_property(text_revisions):
     return "".join(["%s\t%s\n" % (urllib.quote(path.encode("utf-8")), text_revisions[path]) for path in sorted(text_revisions.keys())])
 
 
 class BzrSvnMappingFileProps(object):
+
     def __init__(self, name):
         self.name = name
 
     def import_revision_fileprops(self, fileprops, rev):
         if SVN_PROP_BZR_LOG in fileprops:
-            rev.message = fileprops[SVN_PROP_BZR_LOG][1]
+            rev.message = fileprops[SVN_PROP_BZR_LOG][1].decode("utf-8")
+            assert type(rev.message) is unicode
         metadata = fileprops.get(SVN_PROP_BZR_REVISION_INFO)
         if metadata is not None:
             assert isinstance(metadata, tuple)
@@ -682,13 +639,6 @@ class BzrSvnMappingFileProps(object):
             return True
         return False
 
-    def import_text_parents_fileprops(self, fileprops):
-        metadata = fileprops.get(SVN_PROP_BZR_TEXT_PARENTS)
-        if metadata is None:
-            return {}
-        assert isinstance(metadata, tuple)
-        return parse_text_parents_property(metadata[1])
-
     def import_text_revisions_fileprops(self, fileprops):
         metadata = fileprops.get(SVN_PROP_BZR_TEXT_REVISIONS)
         if metadata is None:
@@ -696,12 +646,6 @@ class BzrSvnMappingFileProps(object):
         assert isinstance(metadata, tuple)
         return parse_text_revisions_property(metadata[1])
 
-    def export_text_parents_fileprops(self, text_parents, fileprops):
-        if text_parents != {}:
-            fileprops[SVN_PROP_BZR_TEXT_PARENTS] = generate_text_parents_property(text_parents)
-        elif SVN_PROP_BZR_TEXT_PARENTS in fileprops:
-            fileprops[SVN_PROP_BZR_TEXT_PARENTS] = ""
-
     def export_text_revisions_fileprops(self, text_revisions, fileprops):
         if text_revisions != {}:
             fileprops[SVN_PROP_BZR_TEXT_REVISIONS] = generate_text_revisions_property(text_revisions)
@@ -747,11 +691,14 @@ class BzrSvnMappingFileProps(object):
         """
         # Bazaar Parents
         old = fileprops.get(SVN_PROP_BZR_ANCESTRY+self.name, "")
-        svnprops = { SVN_PROP_BZR_ANCESTRY+self.name: old + "\t".join(merges) + "\n" }
+        svnprops = {
+            SVN_PROP_BZR_ANCESTRY+self.name: old + "\t".join(merges) + "\n"
+            }
 
         return svnprops
 
-    def export_revision_fileprops(self, timestamp, timezone, committer, revprops, revision_id, revno, parent_ids, svn_fileprops):
+    def export_revision_fileprops(self, timestamp, timezone, committer,
+        revprops, revision_id, revno, parent_ids, svn_fileprops):
 
         # Keep track of what Subversion properties to set later on
         svn_fileprops[SVN_PROP_BZR_REVISION_INFO] = generate_revision_metadata(
@@ -827,7 +774,6 @@ class BzrSvnMappingFileProps(object):
             checkresult.invalid_fileprop_cnt += 1
 
 
-
 class BzrSvnMappingRevProps(object):
 
     def import_revision_revprops(self, svn_revprops, rev):
@@ -838,15 +784,6 @@ class BzrSvnMappingRevProps(object):
             return {}
         return parse_fileid_property(svn_revprops[SVN_REVPROP_BZR_FILEIDS])
 
-    def import_text_parents_revprops(self, svn_revprops):
-        if not svn_revprops.has_key(SVN_REVPROP_BZR_TEXT_PARENTS):
-            return {}
-        return parse_text_parents_property(svn_revprops[SVN_REVPROP_BZR_TEXT_PARENTS])
-
-    def export_text_parents_revprops(self, text_parents, svn_revprops):
-        if text_parents != {}:
-            svn_revprops[SVN_REVPROP_BZR_TEXT_PARENTS] = generate_text_parents_property(text_parents)
-
     def import_text_revisions_revprops(self, svn_revprops):
         if not svn_revprops.has_key(SVN_REVPROP_BZR_TEXT_REVISIONS):
             return {}
@@ -879,7 +816,8 @@ class BzrSvnMappingRevProps(object):
     def export_message_revprops(self, message, revprops):
         revprops[SVN_REVPROP_BZR_LOG] = message.encode("utf-8")
 
-    def export_revision_revprops(self, uuid, branch_root, timestamp, timezone, committer, revprops, revision_id, revno, parent_ids, svn_revprops):
+    def export_revision_revprops(self, uuid, branch_root, timestamp, timezone,
+        committer, revprops, revision_id, revno, parent_ids, svn_revprops):
         svn_revprops[SVN_REVPROP_BZR_MAPPING_VERSION] = self.name
         if timestamp is not None:
             svn_revprops[SVN_REVPROP_BZR_TIMESTAMP] = format_highres_date(timestamp, timezone)
@@ -962,6 +900,11 @@ mapping_registry.set_default('v4')
 
 
 def find_mapping_revprops(revprops):
+    """Find a bzr<->svn mapping based on a set of revision properties.
+
+    :param revprops: Dictionary with revision properties
+    :return: BzrSvnMapping instance, or None if none found
+    """
     if SVN_REVPROP_BZR_MAPPING_VERSION in revprops:
         try:
             return mapping_registry.parse_mapping_name("svn-" + revprops[SVN_REVPROP_BZR_MAPPING_VERSION])
