@@ -19,17 +19,13 @@
 
 
 from bzrlib import (
+    errors,
     trace,
     )
 from bzrlib.bzrdir import (
     BzrDirFormat,
     BzrDir,
-    )
-from bzrlib.errors import (
-    AlreadyBranchError,
-    NotBranchError,
-    NotLocalUrl,
-    NoWorkingTree,
+    format_registry,
     )
 from bzrlib.revision import (
     NULL_REVISION,
@@ -44,7 +40,6 @@ from bzrlib.plugins.svn.errors import (
     )
 from bzrlib.plugins.svn.format import (
     SvnRemoteFormat,
-    get_rich_root_format,
     )
 from bzrlib.plugins.svn.repository import (
     SvnRepository,
@@ -97,7 +92,7 @@ class SvnRemoteAccess(BzrDir):
         self.svn_root_url = _transport.get_svn_repos_root()
         self.root_url = _transport.get_repos_root()
 
-        assert svn_url.startswith(self.svn_root_url)
+        assert svn_url.lower().startswith(self.svn_root_url.lower())
         self.branch_path = svn_url[len(self.svn_root_url):]
 
     def clone(self, url, revision_id=None, force_new_repo=False):
@@ -143,7 +138,7 @@ class SvnRemoteAccess(BzrDir):
 
     def cloning_metadir(self, require_stacking=False):
         """Produce a metadir suitable for cloning with."""
-        return get_rich_root_format(require_stacking)
+        return format_registry.make_bzrdir('default')
 
     def open_workingtree(self, _unsupported=False,
             recommend_upgrade=True):
@@ -153,7 +148,7 @@ class SvnRemoteAccess(BzrDir):
         BzrDir can not be associated with working trees.
         """
         # Working trees never exist on remote Subversion repositories
-        raise NoWorkingTree(self.root_transport.base)
+        raise errors.NoWorkingTree(self.root_transport.base)
 
     def create_workingtree(self, revision_id=None, hardlink=None):
         """See BzrDir.create_workingtree().
@@ -161,7 +156,7 @@ class SvnRemoteAccess(BzrDir):
         Will always raise NotLocalUrl as this
         BzrDir can not be associated with working trees.
         """
-        raise NotLocalUrl(self.root_transport.base)
+        raise errors.NotLocalUrl(self.root_transport.base)
 
     def needs_format_conversion(self, format=None):
         """See BzrDir.needs_format_conversion()."""
@@ -194,9 +189,9 @@ class SvnRemoteAccess(BzrDir):
                 try:
                     (type, project, _, ip) = layout.parse(target_branch_path)
                 except NotSvnBranchPath:
-                    raise NotBranchError(target_branch_path)
+                    raise errors.NotBranchError(target_branch_path)
                 if type not in ('branch', 'tag') or ip != '':
-                    raise NotBranchError(target_branch_path)
+                    raise errors.NotBranchError(target_branch_path)
                 inter.push_new_branch(layout, project, target_branch_path,
                         stop_revision,
                         override_svn_revprops=_override_svn_revprops,
@@ -217,14 +212,16 @@ class SvnRemoteAccess(BzrDir):
             repos.transport.mkdir(self.branch_path.strip("/"))
         elif repos.get_latest_revnum() > 0:
             # Bail out if there are already revisions in this repository
-            raise AlreadyBranchError(self.root_transport.base)
+            raise errors.AlreadyBranchError(self.root_transport.base)
         branch = SvnBranch(repos, self.branch_path)
         branch.bzrdir = self
         return branch
 
-    def open_branch(self, unsupported=True, ignore_fallbacks=False):
+    def open_branch(self, unsupported=True, name=None, ignore_fallbacks=False):
         """See BzrDir.open_branch()."""
         from bzrlib.plugins.svn.branch import SvnBranch
+        if name is not None:
+            raise errors.NoColocatedBranchSupport(self)
         repos = self.find_repository()
         branch = SvnBranch(repos, self.branch_path)
         branch.bzrdir = self
@@ -253,7 +250,7 @@ class SvnRemoteAccess(BzrDir):
                     overwrite=overwrite)
             finally:
                 target_branch.unlock()
-        except NotBranchError:
+        except errors.NotBranchError:
             ret.target_branch_path = "/%s" % self.branch_path.lstrip("/")
             if create_prefix:
                 self.root_transport.create_prefix()
