@@ -30,6 +30,7 @@ from itertools import (
     imap,
     )
 from subvertpy import (
+    NODE_DIR,
     properties,
     )
 
@@ -67,6 +68,9 @@ from bzrlib.plugins.svn.svk import (
     svk_features_merged_since,
     SVN_PROP_SVK_MERGE,
     )
+from bzrlib.plugins.svn.util import (
+    ListBuildingIterator,
+    )
 
 # Maximum number of revisions to browse for a cached copy of the branch
 # file properties
@@ -106,6 +110,14 @@ class RevisionMetadata(object):
     from other known data before contacting the Subversions server.
     """
 
+    __slots__ = ('repository', 'check_revprops', '_get_fileprops_fn',
+                 '_log', 'branch_path', '_paths', 'revnum', '_revprops',
+                 '_changed_fileprops', '_fileprops',
+                 '_direct_lhs_parent_known', '_consider_bzr_fileprops',
+                 '_consider_bzr_revprops', '_estimated_fileprop_ancestors',
+                 'metaiterators', 'uuid', 'children',
+                 '_direct_lhs_parent_revmeta', '_revprop_redirect_revnum')
+
     def __init__(self, repository, check_revprops, get_fileprops_fn, logwalker,
                  uuid, branch_path, revnum, paths, revprops,
                  changed_fileprops=None, fileprops=None,
@@ -218,10 +230,13 @@ class RevisionMetadata(object):
             while (not lm.changes_branch_root() and lm._fileprops is None and
                    len(todo) < MAX_FILEPROP_SHARED):
                 todo.add(lm)
-                lm = lm.get_direct_lhs_parent_revmeta()
+                nlm = lm.get_direct_lhs_parent_revmeta()
+                assert nlm is not None, \
+                        "no lhs parent revmeta found for %r" % lm
+                lm = nlm
             if lm._fileprops is None:
                 lm._fileprops = self._get_fileprops_fn(lm.branch_path,
-                                                       lm.revnum)
+                    lm.revnum)
             for r in todo:
                 r._fileprops = lm._fileprops
         return self._fileprops
@@ -230,7 +245,6 @@ class RevisionMetadata(object):
         """Get the revision properties set on the revision."""
         if self._revprops is None:
             self._revprops = self._log.revprop_list(self.revnum)
-
         return self._revprops
 
     def knows_changed_fileprops(self):
@@ -238,7 +252,8 @@ class RevisionMetadata(object):
         if self._changed_fileprops is None:
             return False
         changed_fileprops = self.get_changed_fileprops()
-        return isinstance(changed_fileprops, dict) or changed_fileprops.is_loaded
+        return (isinstance(changed_fileprops, dict) or
+                changed_fileprops.is_loaded)
 
     def knows_fileprops(self):
         """Check whether the file properties can be cheaply retrieved."""
@@ -305,8 +320,8 @@ class RevisionMetadata(object):
                 return self._direct_lhs_parent_revmeta
             except MetaHistoryIncomplete:
                 pass
-        iterator = self.repository._revmeta_provider.iter_reverse_branch_changes(self.branch_path,
-            self.revnum, to_revnum=0, limit=0)
+        iterator = self.repository._revmeta_provider.iter_reverse_branch_changes(
+                self.branch_path, self.revnum, to_revnum=0, limit=0)
         firstrevmeta = iterator.next()
         assert self == firstrevmeta, "Expected %r got %r" % (self, firstrevmeta)
         try:
@@ -462,7 +477,6 @@ class RevisionMetadata(object):
 
     def estimate_bzr_fileprop_ancestors(self):
         """Estimate how many ancestors with bzr fileprops this revision has.
-
         """
         return self._estimate_fileprop_ancestors("bzr:", estimate_bzr_ancestors)
 
@@ -519,6 +533,7 @@ class RevisionMetadata(object):
         """Determine the Bazaar revision number for this revision.
 
         :param mapping: Mapping to use
+        :return: Bazaar revision number
         """
         extra = 0
         total_hidden = None
@@ -544,6 +559,7 @@ class RevisionMetadata(object):
     def get_rhs_parents(self, mapping):
         """Determine the right hand side parent ids for this revision.
 
+        :param mapping:
         """
         return self._get_rhs_parents(mapping)
 
@@ -714,13 +730,6 @@ class RevisionMetadata(object):
             mapping.import_text_revisions_revprops, {},
             self.consider_bzr_fileprops)
 
-    def get_text_parents(self, mapping):
-        """Return text revision override map for this revision."""
-        return self._import_from_props(mapping,
-            mapping.import_text_parents_fileprops,
-            mapping.import_text_parents_revprops, {},
-            self.consider_bzr_fileprops)
-
     def consider_bzr_revprops(self):
         """See if bzr revision properties should be checked at all.
 
@@ -797,6 +806,10 @@ class RevisionMetadata(object):
 class CachingRevisionMetadata(RevisionMetadata):
     """Wrapper around RevisionMetadata that stores some results in a cache."""
 
+    __slots__ = ('base', '_revid_cache', '_revinfo_cache', '_revision_info',
+                 '_original_mapping', '_original_mapping_set',
+                 '_stored_lhs_parent_revid', '_parents_cache', 'paths')
+
     def __init__(self, repository, *args, **kwargs):
         self.base = super(CachingRevisionMetadata, self)
         self.base.__init__(repository, *args,
@@ -835,7 +848,6 @@ class CachingRevisionMetadata(RevisionMetadata):
     def get_original_mapping(self):
         if self._original_mapping_set:
             return self._original_mapping
-
         try:
             self._original_mapping = self._revinfo_cache.get_original_mapping(
                 self.get_foreign_revid())
@@ -913,30 +925,12 @@ def svk_feature_to_revision_id(feature, mapping):
     return mapping.revision_id_foreign_to_bzr((uuid, bp, revnum))
 
 
-class ListBuildingIterator(object):
-    """Simple iterator that iterates over a list, and calling an iterator
-    once all items in the list have been iterated.
-
-    The list may be updated while the iterator is running.
-    """
-
-    def __init__(self, base_list, it):
-        self.base_list = base_list
-        self.i = -1
-        self.it = it
-
-    def next(self):
-        """Return the next item."""
-        self.i+=1
-        try:
-            return self.base_list[self.i]
-        except IndexError:
-            return self.it()
-
-
 class RevisionMetadataBranch(object):
     """Describes a Bazaar-like branch in a Subversion repository."""
 
+    __slots__ = ('_revs', '_revnums', '_history_limit', '_revmeta_provider',
+                 '_get_next')
+
     def __init__(self, revmeta_provider=None, history_limit=None):
         self._revs = []
         self._revnums = []
@@ -1160,7 +1154,7 @@ class RevisionMetadataBrowser(object):
             deletes = []
 
             if paths == {}:
-                paths = {"": ("M", None, -1)}
+                paths = {"": ("M", None, -1, NODE_DIR)}
 
             # Find out what branches have changed
             for p in sorted(paths):
@@ -1205,7 +1199,7 @@ class RevisionMetadataBrowser(object):
                 yield "revision", revmeta
 
             # Apply reverse renames and the like for the next round
-            for new_name, old_name, old_rev in changes.apply_reverse_changes(
+            for new_name, old_name, old_rev, kind in changes.apply_reverse_changes(
                 self._ancestors.keys(), paths):
                 self._unusual.discard(new_name)
                 if old_name is None:
@@ -1225,7 +1219,7 @@ class RevisionMetadataBrowser(object):
 
             # Update the prefixes, if necessary
             if self._prefixes:
-                for new_name, old_name, old_rev in changes.apply_reverse_changes(
+                for new_name, old_name, old_rev, kind in changes.apply_reverse_changes(
                     self._prefixes, paths):
                     if old_name is None:
                         # Didn't exist previously, terminate prefix
@@ -1320,7 +1314,7 @@ class RevisionMetadataProvider(object):
         if self.in_cache(path, revnum):
             cached = self._revmeta_cache[path,revnum]
             if changes is not None:
-                cached.paths = changes
+                cached._paths = changes
             if cached._changed_fileprops is None:
                 cached._changed_fileprops = changed_fileprops
             if cached._fileprops is None:
