@@ -22,6 +22,7 @@ import subvertpy
 from bzrlib import urlutils
 from bzrlib.branch import (
     Branch,
+    InterBranch,
     )
 from bzrlib.bzrdir import (
     BzrDir,
@@ -52,7 +53,8 @@ class WorkingSubversionBranch(SubversionTestCase):
         repos_url = self.make_repository("a")
         branch = Branch.open(repos_url)
         branch.revision_history()
-        self.assertEqual(branch.generate_revision_id(0), branch.last_revision())
+        self.assertEqual(branch.generate_revision_id(0),
+                         branch.last_revision())
 
     def test_get_branch_path_root(self):
         repos_url = self.make_repository("a")
@@ -111,7 +113,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         b.tags.set_tag(u"mytag",
             b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
 
-        self.assertEquals(subvertpy.NODE_DIR, 
+        self.assertEquals(subvertpy.NODE_DIR,
                 b.repository.transport.check_path("tags/mytag", 3))
 
     def test_tag_set_dupe(self):
@@ -131,7 +133,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         target = b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping())
         b.tags.set_tag(u"mytag", b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
 
-        self.assertEquals(subvertpy.NODE_DIR, 
+        self.assertEquals(subvertpy.NODE_DIR,
                 b.repository.transport.check_path("tags/mytag", 3))
         self.assertEquals(3, b.repository.get_latest_revnum())
 
@@ -157,7 +159,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         b = Branch.open(repos_url + "/trunk")
         b.tags.set_tag(u"mytag", b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
 
-        self.assertEquals(subvertpy.NODE_DIR, 
+        self.assertEquals(subvertpy.NODE_DIR,
                 b.repository.transport.check_path("tags/mytag", 3))
         self.assertEquals(3, b.repository.get_latest_revnum())
 
@@ -168,13 +170,13 @@ class WorkingSubversionBranch(SubversionTestCase):
         newtagrevid = b.repository.generate_revision_id(2, "trunk", b.repository.get_mapping())
         b.tags.set_tag(u"mytag", newtagrevid)
 
-        self.assertEquals(subvertpy.NODE_DIR, 
+        self.assertEquals(subvertpy.NODE_DIR,
                 b.repository.transport.check_path("tags/mytag", 4))
         self.assertEquals(4, b.repository.get_latest_revnum())
         b = Branch.open(repos_url + "/trunk")
         log = self.client_log(repos_url, 4, 0)
         self.assertEquals(log[0][0], None)
-        self.assertEquals(log[1][0], {'/tags': ('A', None, -1), 
+        self.assertEquals(log[1][0], {'/tags': ('A', None, -1),
                                       '/trunk': ('A', None, -1)})
         self.assertEquals(log[2][0], {'/trunk/bla': ('A', None, -1)})
         self.assertEquals(log[3][0], {'/tags/mytag': ('A', '/trunk', 1)})
@@ -184,7 +186,7 @@ class WorkingSubversionBranch(SubversionTestCase):
 
     def test_tags_delete(self):
         repos_url = self.make_repository("a")
-       
+
         dc = self.get_commit_editor(repos_url)
         tags = dc.add_dir("tags")
         tags.add_dir("tags/foo")
@@ -197,7 +199,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         b = Branch.open(repos_url + "/trunk")
         self.assertEquals([], b.tags.get_tag_dict().keys())
 
-    def test_tag_set_no_parent_Dir(self):
+    def test_tag_set_no_parent_dir(self):
         repos_url = self.make_repository('a')
 
         dc = self.get_commit_editor(repos_url)
@@ -211,12 +213,13 @@ class WorkingSubversionBranch(SubversionTestCase):
 
         b = Branch.open(repos_url + "/trunk")
         b.tags.set_tag(u"mytag",
-            b.repository.generate_revision_id(1, "trunk", b.repository.get_mapping()))
+            b.repository.generate_revision_id(1, "trunk",
+                b.repository.get_mapping()))
 
-        self.assertEquals(subvertpy.NODE_DIR, 
+        self.assertEquals(subvertpy.NODE_DIR,
                 b.repository.transport.check_path("tags", 3))
 
-        self.assertEquals(subvertpy.NODE_DIR, 
+        self.assertEquals(subvertpy.NODE_DIR,
                 b.repository.transport.check_path("tags/mytag", 4))
         self.assertEquals(4, b.repository.get_latest_revnum())
 
@@ -230,12 +233,13 @@ class WorkingSubversionBranch(SubversionTestCase):
 
         b = Branch.open(repos_url + "/trunk/gui")
         self.assertRaises(TagsNotSupported,
-                b.tags.set_tag, u"mytag", 
-                b.repository.generate_revision_id(1, "trunk/gui", b.repository.get_mapping()))
+            b.tags.set_tag, u"mytag",
+            b.repository.generate_revision_id(1, "trunk/gui",
+                b.repository.get_mapping()))
 
     def test_tag_lookup(self):
         repos_url = self.make_repository("a")
-       
+
         dc = self.get_commit_editor(repos_url)
         tags = dc.add_dir("tags")
         tags.add_dir("tags/foo")
@@ -244,7 +248,10 @@ class WorkingSubversionBranch(SubversionTestCase):
 
         b = Branch.open(repos_url + "/trunk")
         self.assertEquals("", b.project)
-        self.assertEquals(b.repository.generate_revision_id(1, "tags/foo", b.repository.get_mapping()), b.tags.lookup_tag("foo"))
+        self.assertEquals(
+            b.repository.generate_revision_id(1, "tags/foo",
+                b.repository.get_mapping()),
+            b.tags.lookup_tag("foo"))
 
     def test_tag_lookup_nonexistant(self):
         repos_url = self.make_repository("a")
@@ -252,7 +259,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         dc = self.get_commit_editor(repos_url)
         dc.add_dir("trunk")
         dc.close()
-       
+
         b = Branch.open(repos_url + "/trunk")
         self.assertRaises(NoSuchTag, b.tags.lookup_tag, "foo")
 
@@ -262,7 +269,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         dc = self.get_commit_editor(repos_url)
         dc.add_dir("trunk")
         dc.close()
-       
+
         b = Branch.open(repos_url + "/trunk")
         self.assertRaises(NoSuchTag, b.tags.delete_tag, u"foo")
 
@@ -305,6 +312,70 @@ class WorkingSubversionBranch(SubversionTestCase):
         self.assertEquals(result.source_branch, otherbranch)
         self.assertEquals(result.target_branch, branch)
 
+    def make_tworev_branch(self):
+        repos_url = self.make_repository("a")
+
+        dc = self.get_commit_editor(repos_url)
+        dc.add_file('foo')
+        dc.close()
+
+        b = Branch.open(repos_url)
+        mapping = b.repository.get_mapping()
+        uuid = b.repository.uuid
+        revid1 = mapping.revision_id_foreign_to_bzr((uuid, '', 0))
+        revid2 = mapping.revision_id_foreign_to_bzr((uuid, '', 1))
+        return b, (revid1, revid2)
+
+    def make_branch(self, relpath):
+        # The inherited make_branch is broken, thanks to the make_repository
+        # from subvertpy.
+        bzrdir = self.make_bzrdir(relpath)
+        bzrdir._find_or_create_repository(True)
+        return bzrdir.create_branch()
+
+    def test_interbranch_pull(self):
+        svn_branch, (revid1, revid2) = self.make_tworev_branch()
+        new_branch = self.make_branch("b")
+        inter_branch = InterBranch.get(svn_branch, new_branch)
+        inter_branch.pull()
+        self.assertEquals(revid2, new_branch.last_revision())
+
+    def test_interbranch_pull_noop(self):
+        svn_branch, (revid1, revid2) = self.make_tworev_branch()
+        new_branch = self.make_branch("b")
+        inter_branch = InterBranch.get(svn_branch, new_branch)
+        inter_branch.pull()
+        # This is basically "assertNotRaises"
+        inter_branch.pull()
+        self.assertEquals(revid2, new_branch.last_revision())
+
+    def test_interbranch_pull_stop_revision(self):
+        svn_branch, (revid1, revid2) = self.make_tworev_branch()
+        new_branch = self.make_branch("b")
+        inter_branch = InterBranch.get(svn_branch, new_branch)
+        inter_branch.pull(stop_revision=revid1)
+        self.assertEquals(revid1, new_branch.last_revision())
+
+    def test_interbranch_limited_pull(self):
+        svn_branch, (revid1, revid2) = self.make_tworev_branch()
+        new_branch = self.make_branch("b")
+        inter_branch = InterBranch.get(svn_branch, new_branch)
+        inter_branch.pull(limit=1)
+        self.assertEquals(revid1, new_branch.last_revision())
+        inter_branch.pull(limit=1)
+        self.assertEquals(revid2, new_branch.last_revision())
+
+    def test_interbranch_limited_overwrite(self):
+        svn_branch, (revid1, revid2) = self.make_tworev_branch()
+        new_branch = self.make_branch("b")
+        inter_branch = InterBranch.get(svn_branch, new_branch)
+        inter_branch.pull(limit=2)
+        self.assertEquals(revid2, new_branch.last_revision())
+        inter_branch.pull(limit=1, stop_revision=revid1)
+        self.assertEquals(revid2, new_branch.last_revision())
+        inter_branch.pull(limit=1, overwrite=True, stop_revision=revid1)
+        self.assertEquals(revid1, new_branch.last_revision())
+
     def test_get_branch_path_subdir(self):
         repos_url = self.make_repository("a")
 
@@ -315,6 +386,29 @@ class WorkingSubversionBranch(SubversionTestCase):
         branch = Branch.open(repos_url+"/trunk")
         self.assertEqual("trunk", branch.get_branch_path())
 
+    def test_tag_added_later(self):
+        repos_url = self.make_repository("a")
+
+        dc = self.get_commit_editor(repos_url)
+        dc.add_dir("trunk")
+        dc.close()
+
+        olddir = BzrDir.open(repos_url+"/trunk")
+        oldbranch = olddir.open_branch()
+        newdir = olddir.sprout("mycopy")
+        newbranch = newdir.open_branch()
+        self.assertEquals({}, newbranch.tags.get_tag_dict())
+
+        dc = self.get_commit_editor(repos_url)
+        tags = dc.add_dir("tags")
+        new_tag = tags.add_dir("tags/newtag", "trunk")
+        dc.close()
+
+        self.assertEquals(1, oldbranch.get_revnum())
+        newbranch.pull(oldbranch, stop_revision=oldbranch.last_revision())
+
+        self.assertEquals(["newtag"], newbranch.tags.get_tag_dict().keys())
+
     def test_open_nonexistant(self):
         repos_url = self.make_repository("a")
         self.assertRaises(NotBranchError, Branch.open, repos_url + "/trunk")
@@ -331,13 +425,13 @@ class WorkingSubversionBranch(SubversionTestCase):
     def test_lookup_revision_id_unknown(self):
         repos_url = self.make_repository("a")
         branch = Branch.open(repos_url)
-        self.assertRaises(NoSuchRevision, 
+        self.assertRaises(NoSuchRevision,
                 lambda: branch.lookup_bzr_revision_id("bla"))
 
     def test_lookup_revision_id(self):
         repos_url = self.make_repository("a")
         branch = Branch.open(repos_url)
-        self.assertEquals(0, 
+        self.assertEquals(0,
                 branch.lookup_bzr_revision_id(branch.last_revision()))
 
     def test_set_parent(self):
@@ -355,14 +449,14 @@ class WorkingSubversionBranch(SubversionTestCase):
         dc = self.get_commit_editor(repos_url)
         dc.add_file("foo").modify()
         dc.close()
-        
+
         bzrdir = BzrDir.open(repos_url)
         branch = bzrdir.open_branch()
         repos = bzrdir.find_repository()
-        
+
         mapping = repos.get_mapping()
 
-        self.assertEqual(repos.generate_revision_id(1, "", mapping), 
+        self.assertEqual(repos.generate_revision_id(1, "", mapping),
                 branch.last_revision())
 
         dc = self.get_commit_editor(repos_url)
@@ -458,7 +552,7 @@ class WorkingSubversionBranch(SubversionTestCase):
         repos_url = self.make_repository('a')
         branch = Branch.open(repos_url)
         self.assertRaises(NoSuchRevision, branch.revision_id_to_revno, "bla")
-    
+
     def test_get_nick_none(self):
         repos_url = self.make_repository('a')
 
@@ -486,7 +580,7 @@ class WorkingSubversionBranch(SubversionTestCase):
 
         dc = self.get_commit_editor(repos_url)
         dc.add_file("foo").modify()
-        dc.change_prop("bzr:revision-info", 
+        dc.change_prop("bzr:revision-info",
                 "properties: \n\tbranch-nick: mybranch\n")
         dc.close()
 
@@ -734,12 +828,12 @@ foohosts""")
 
         host_fileid = tree.inventory.path2id("hosts")
 
-        self.assertVersionsPresentEquals(newbranch.repository.texts, 
+        self.assertVersionsPresentEquals(newbranch.repository.texts,
                                         host_fileid, [
             oldbranch.generate_revision_id(6),
             oldbranch.generate_revision_id(7)])
         newbranch.unlock()
- 
+
 
     def test_fetch_odd(self):
         repos_url = self.make_repository('d')
@@ -807,8 +901,8 @@ foohosts""")
         self.make_repository('d')
         branch = Branch.open('d')
         result = branch.check()
-        self.assertEqual(branch, result.branch) 
- 
+        self.assertEqual(branch, result.branch)
+
     def test_generate_revision_id(self):
         repos_url = self.make_repository('d')
 
@@ -887,7 +981,7 @@ foohosts""")
         olddir = BzrDir.open("sc")
 
         os.mkdir("dc")
-        
+
         newdir = olddir.sprout('dc')
 
         self.assertEqual(
@@ -913,7 +1007,7 @@ foohosts""")
         olddir = BzrDir.open("sc/branches/abranch")
 
         os.mkdir("dc")
-        
+
         newdir = olddir.sprout('dc')
 
         self.assertEqual(
@@ -939,7 +1033,7 @@ foohosts""")
         olddir = BzrDir.open("sc/trunk")
 
         os.mkdir("dc")
-        
+
         newdir = olddir.sprout('dc')
 
         self.assertEqual(
@@ -949,7 +1043,7 @@ foohosts""")
 
 
     def test_ghost_workingtree(self):
-        # Looks like bazaar has trouble creating a working tree of a 
+        # Looks like bazaar has trouble creating a working tree of a
         # revision that has ghost parents
         repos_url = self.make_client('d', 'sc')
 
@@ -962,11 +1056,11 @@ foohosts""")
         olddir = BzrDir.open("sc")
 
         os.mkdir("dc")
-        
+
         newdir = olddir.sprout('dc')
         newdir.find_repository().get_revision(
                 newdir.open_branch().last_revision())
-        newdir.find_repository().get_revision_inventory(
+        newdir.find_repository().get_inventory(
                 newdir.open_branch().last_revision())
 
 
@@ -980,18 +1074,18 @@ class BranchFormatTests(TestCase):
         self.assertRaises(NotImplementedError, self.format.initialize, None)
 
     def test_get_format_string(self):
-        self.assertEqual("Subversion Smart Server", 
+        self.assertEqual("Subversion Smart Server",
                          self.format.get_format_string())
 
     def test_get_format_description(self):
-        self.assertEqual("Subversion Smart Server", 
+        self.assertEqual("Subversion Smart Server",
                          self.format.get_format_description())
 
 
 class ForeignTestsBranchFactory(object):
 
     def make_empty_branch(self, transport):
-        raise TestSkipped
+        raise TestSkipped()
 
     def make_branch(self, transport):
         subvertpy.repos.create(transport.local_abspath("."))
