@@ -23,6 +23,8 @@ import os
 import shutil
 import sys
 
+from subvertpy import NODE_DIR, NODE_FILE
+
 from bzrlib.branch import (
     Branch,
     )
@@ -99,7 +101,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(1))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -147,17 +149,17 @@ class TestFetchWorks(FetchTestCase):
         self.client_copy("dc/trunk", "dc/tags/R_0_9_2", revnum=2)
         self.client_delete("dc/tags/R_0_9_2/check/debian")
         shutil.rmtree("dc/tags/R_0_9_2/check/debian")
-        self.client_copy("dc/trunk/check/debian", "dc/tags/R_0_9_2/check", 
+        self.client_copy("dc/trunk/check/debian", "dc/tags/R_0_9_2/check/debian",
                          revnum=5)
         self.client_delete("dc/tags/R_0_9_2/check/stamp-h.in")
-        self.client_copy("dc/trunk/check/stamp-h.in", "dc/tags/R_0_9_2/check", 
+        self.client_copy("dc/trunk/check/stamp-h.in", "dc/tags/R_0_9_2/check/stamp-h.in",
                          revnum=4)
         self.build_tree({"dc/tags/R_0_9_2/check/debian/blie": "oehha"})
         self.client_update("dc")
         self.client_commit("dc", "strange revision") # 6
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -173,22 +175,22 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
-        self.assertRaises(InvalidFileName, self.copy_content, oldrepos, 
+        self.assertRaises(InvalidFileName, self.copy_content, oldrepos,
                 newrepos)
 
     def test_fetch_null(self):
         repos_url = self.make_repository('d')
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(1))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos, NULL_REVISION)
 
     def test_fetch_copy_remove_old(self):
         repos_url = self.make_client('d', 'dc')
-        self.build_tree({'dc/trunk/afile': 'foo', 'dc/tags': None, 
+        self.build_tree({'dc/trunk/afile': 'foo', 'dc/tags': None,
                          'dc/branches': None})
         self.client_add("dc/trunk")
         self.client_add("dc/tags")
@@ -205,7 +207,7 @@ class TestFetchWorks(FetchTestCase):
         self.client_commit("dc", "My Message")
         self.client_update("dc")
         oldrepos = Repository.open(repos_url)
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -219,7 +221,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -232,7 +234,7 @@ class TestFetchWorks(FetchTestCase):
         self.client_set_revprop(repos_url, 1, "bzr:gpg-signature", "SIGNATURE")
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         self.assertEquals("SIGNATURE", newrepos.get_signature_text(oldrepos.generate_revision_id(1, "trunk", oldrepos.get_mapping())))
@@ -245,13 +247,13 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
     def test_fetch_special_char_edit(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         trunk = dc.add_dir("trunk")
         trunk.add_dir(u'trunk/IöC'.encode("utf-8"))
@@ -264,13 +266,13 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
     def test_fetch_special_char_child(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         trunk = dc.add_dir("trunk")
         raardir = trunk.add_dir(u"trunk/é".encode("utf-8"))
@@ -278,7 +280,7 @@ class TestFetchWorks(FetchTestCase):
         dc.close()
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -297,7 +299,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -309,7 +311,7 @@ class TestFetchWorks(FetchTestCase):
         foo.add_file("foo/bla").modify("data")
         dc.close()
         oldrepos = Repository.open(repos_url)
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -337,7 +339,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -364,7 +366,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -404,9 +406,9 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        to_bzrdir = BzrDir.create("f", format.get_rich_root_format())
+        to_bzrdir = BzrDir.create("f")
         repo = to_bzrdir.create_repository()
-        last_rev = oldrepos.generate_revision_id(3, "branch2", 
+        last_rev = oldrepos.generate_revision_id(3, "branch2",
             oldrepos.get_mapping())
         self.fetch(oldrepos, repo, last_rev)
         self.assertEquals(repo.get_inventory(last_rev).root.file_id,
@@ -428,7 +430,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -464,7 +466,7 @@ class TestFetchWorks(FetchTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -550,7 +552,7 @@ Node-action: delete
         load_dumpfile("dumpfile", "old")
         oldrepos = Repository.open("old")
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -692,7 +694,7 @@ Node-copyfrom-path: u
         load_dumpfile("dumpfile", "old")
         oldrepos = Repository.open("old")
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -839,7 +841,7 @@ Node-copyfrom-path: bla
         load_dumpfile("dumpfile", "old")
         oldrepos = Repository.open("old")
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1020,7 +1022,7 @@ Node-copyfrom-path: bla
         load_dumpfile("dumpfile", "old")
         oldrepos = Repository.open("old")
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1155,14 +1157,14 @@ Node-action: add
 Node-copyfrom-rev: 1
 Node-copyfrom-path: x
 
-                
+
 """)
         os.mkdir("old")
 
         load_dumpfile("dumpfile", "old")
         oldrepos = Repository.open("old")
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1326,7 +1328,7 @@ Node-copyfrom-path: x
         load_dumpfile("dumpfile", "old")
         oldrepos = Repository.open("old")
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1378,7 +1380,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         lastrevid = oldrepos.generate_revision_id(4, "branches/1.0", oldrepos.get_mapping())
@@ -1401,17 +1403,17 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
         branch = Branch.open("%s/branches/mybranch" % repos_url)
         mapping = oldrepos.get_mapping()
         if mapping.is_branch("trunk/lib"):
-            self.assertEqual([oldrepos.generate_revision_id(1, "trunk/lib", mapping), oldrepos.generate_revision_id(2, "branches/mybranch", mapping)], 
+            self.assertEqual([oldrepos.generate_revision_id(1, "trunk/lib", mapping), oldrepos.generate_revision_id(2, "branches/mybranch", mapping)],
                              branch.revision_history())
         else:
-            self.assertEqual([oldrepos.generate_revision_id(2, "branches/mybranch", mapping)], 
+            self.assertEqual([oldrepos.generate_revision_id(2, "branches/mybranch", mapping)],
                              branch.revision_history())
 
     def test_fetch_dir_from_non_branch(self):
@@ -1430,7 +1432,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -1453,17 +1455,19 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
         branch = Branch.open("%s/trunk" % repos_url)
         if oldrepos.get_mapping().is_branch("old-trunk"):
-            self.assertEqual([oldrepos.generate_revision_id(1, "old-trunk", oldrepos.get_mapping()), 
-                              oldrepos.generate_revision_id(2, "trunk", oldrepos.get_mapping())],
+            self.assertEqual([
+                oldrepos.generate_revision_id(1, "old-trunk", oldrepos.get_mapping()),
+                oldrepos.generate_revision_id(2, "trunk", oldrepos.get_mapping())],
                          branch.revision_history())
         else:
-            self.assertEqual([oldrepos.generate_revision_id(2, "trunk", oldrepos.get_mapping())],
+            self.assertEqual([
+                oldrepos.generate_revision_id(2, "trunk", oldrepos.get_mapping())],
                          branch.revision_history())
 
 
@@ -1484,7 +1488,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -1514,7 +1518,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -1550,7 +1554,8 @@ Node-copyfrom-path: x
         branches.add_dir("branches/foobranch", "trunk")
         dc.close()
 
-        repos = remote.SvnRemoteAccess(SvnRaTransport(repos_url), format.SvnRemoteFormat()).find_repository()
+        repos = remote.SvnRemoteAccess(SvnRaTransport(repos_url),
+                format.SvnRemoteFormat()).find_repository()
         repos.set_layout(TrunkLayout(0))
 
         mapping = repos.get_mapping()
@@ -1558,7 +1563,9 @@ Node-copyfrom-path: x
         tree = repos.revision_tree(
              repos.generate_revision_id(3, "branches/foobranch", mapping))
 
-        self.assertEqual(mapping.generate_file_id((repos.uuid, "trunk", 1), u""), tree.inventory.root.file_id)
+        self.assertEqual(
+            mapping.generate_file_id((repos.uuid, "trunk", 1), u""),
+            tree.inventory.root.file_id)
 
     def test_fetch_odd(self):
         repos_url = self.make_repository('d')
@@ -1611,8 +1618,8 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir1 = BzrDir.create("f", format.get_rich_root_format())
-        dir2 = BzrDir.create("g", format.get_rich_root_format())
+        dir1 = BzrDir.create("f")
+        dir2 = BzrDir.create("g")
         newrepos1 = dir1.create_repository()
         newrepos2 = dir2.create_repository()
         self.copy_content(oldrepos, newrepos1)
@@ -1638,7 +1645,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1664,7 +1671,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1689,7 +1696,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1704,7 +1711,7 @@ Node-copyfrom-path: x
         key = (ie.file_id, ie.revision)
         newrepos.lock_read()
         try:
-            self.assertEquals(sha_string(""), 
+            self.assertEquals(sha_string(""),
                 newrepos.texts.get_sha1s([key])[key])
         finally:
             newrepos.unlock()
@@ -1723,7 +1730,7 @@ Node-copyfrom-path: x
         dc.close()
 
         oldrepos = Repository.open(repos_url)
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1745,7 +1752,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1771,7 +1778,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1797,7 +1804,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1820,7 +1827,7 @@ Node-copyfrom-path: x
         dc.open_file("mylink").change_prop("svn:special", "*")
         dc.close()
         oldrepos = Repository.open(repos_url)
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         oldrepos.set_layout(RootLayout())
         self.copy_content(oldrepos, newrepos)
@@ -1837,7 +1844,7 @@ Node-copyfrom-path: x
 
     def test_fetch_executable_separate(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         dc.add_file("bla").modify("data")
         dc.close()
@@ -1848,7 +1855,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -1860,7 +1867,7 @@ Node-copyfrom-path: x
         inv2 = newrepos.get_inventory(
                 oldrepos.generate_revision_id(2, "", mapping))
         self.assertTrue(inv2[inv2.path2id("bla")].executable)
-        self.assertEqual(oldrepos.generate_revision_id(2, "", mapping), 
+        self.assertEqual(oldrepos.generate_revision_id(2, "", mapping),
                          inv2[inv2.path2id("bla")].revision)
 
     def test_fetch_hidden(self):
@@ -1887,7 +1894,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -1913,11 +1920,11 @@ Node-copyfrom-path: x
         oldrepos = Repository.open(repos_url)
 
         dc = self.get_commit_editor(repos_url)
-        dc.open_dir("trunk").change_prop("svk:merge", 
+        dc.open_dir("trunk").change_prop("svk:merge",
                              "%s:/branches/foo:2\n" % oldrepos.uuid)
         dc.close()
 
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -1963,30 +1970,30 @@ Node-copyfrom-path: x
         repos_url = self.build_intertwined()
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos, "revid4")
         from bzrlib.plugins.svn.mapping3.base import BzrSvnMappingv3
         from bzrlib.plugins.svn.mapping3.scheme import TrunkBranchingScheme
-        revid3 = oldrepos.generate_revision_id(3, "trunk", 
+        revid3 = oldrepos.generate_revision_id(3, "trunk",
                 BzrSvnMappingv3(TrunkBranchingScheme(0)))
-        self.assertEquals(set(["revid1", "revid2", revid3, "revid4"]), 
+        self.assertEquals(set(["revid1", "revid2", revid3, "revid4"]),
                 set(newrepos.all_revision_ids()))
 
     def test_fetch_intertwined_mappings_new(self):
         repos_url = self.build_intertwined()
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         from bzrlib.plugins.svn.mapping4 import BzrSvnMappingv4
         revid5 = oldrepos.generate_revision_id(5, "trunk", BzrSvnMappingv4())
         self.copy_content(oldrepos, newrepos, revid5)
         from bzrlib.plugins.svn.mapping3.base import BzrSvnMappingv3
         from bzrlib.plugins.svn.mapping3.scheme import TrunkBranchingScheme
-        revid3 = oldrepos.generate_revision_id(3, "trunk", 
+        revid3 = oldrepos.generate_revision_id(3, "trunk",
                 BzrSvnMappingv3(TrunkBranchingScheme(0)))
-        self.assertEquals(set(["revid1", "revid2", revid3, "revid4", revid5]), 
+        self.assertEquals(set(["revid1", "revid2", revid3, "revid4", revid5]),
                 set(newrepos.all_revision_ids()))
 
     def test_fetch_property_change_only(self):
@@ -2010,7 +2017,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(RootLayout())
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -2046,7 +2053,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
         mapping = oldrepos.get_mapping()
@@ -2085,10 +2092,12 @@ Node-copyfrom-path: x
         dc.close()
 
         oldrepos = Repository.open(repos_url)
-        self.assertEquals({'trunk/adir': (u'R', 'trunk/adir', 2), 'trunk/adir/foofile': (u'A', None, -1)}, 
-                          oldrepos._revmeta_provider.get_revision("trunk", 3).get_paths())
+        self.assertChangedPathsEquals({
+            'trunk/adir': (u'R', 'trunk/adir', 2, NODE_DIR),
+            'trunk/adir/foofile': (u'A', None, -1, NODE_FILE)},
+              oldrepos._revmeta_provider.get_revision("trunk", 3).get_paths())
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
@@ -2120,16 +2129,18 @@ Node-copyfrom-path: x
         dc.close()
 
         oldrepos = Repository.open(repos_url)
-        self.assertEquals({'trunk/adir': (u'R', 'trunk/adir', 1), 'trunk/adir/foofile': (u'A', None, -1)}, 
-                          oldrepos._revmeta_provider.get_revision("trunk", 3).get_paths())
+        self.assertChangedPathsEquals({
+            'trunk/adir': (u'R', 'trunk/adir', 1, NODE_DIR),
+            'trunk/adir/foofile': (u'A', None, -1, NODE_FILE)},
+              oldrepos._revmeta_provider.get_revision("trunk", 3).get_paths())
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         self.copy_content(oldrepos, newrepos)
 
     def test_fetch_crosscopy(self):
         repos_url = self.make_repository('d')
-        
+
         dc = self.get_commit_editor(repos_url)
         trunk = dc.add_dir("trunk")
         adir = trunk.add_dir("trunk/adir")
@@ -2160,7 +2171,7 @@ Node-copyfrom-path: x
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         mapping = oldrepos.get_mapping()
         copyrev = oldrepos.generate_revision_id(2, "branches/abranch", mapping)
@@ -2169,11 +2180,11 @@ Node-copyfrom-path: x
         self.copy_content(oldrepos, newrepos, lastrev)
 
         inventory = newrepos.get_inventory(lastrev)
-        self.assertEqual(prevrev, 
+        self.assertEqual(prevrev,
                          inventory[inventory.path2id("bdir/afile")].revision)
 
         inventory = newrepos.get_inventory(prevrev)
-        self.assertEqual(copyrev, 
+        self.assertEqual(copyrev,
                          inventory[inventory.path2id("bdir/stationary")].revision)
 
 
