@@ -18,6 +18,8 @@
 
 import os
 
+from subvertpy import NODE_DIR, NODE_FILE
+
 from bzrlib import debug
 from bzrlib.errors import NoSuchRevision
 from bzrlib.tests import TestCase
@@ -28,6 +30,14 @@ from bzrlib.plugins.svn.transport import SvnRaTransport
 
 class TestLogWalker(SubversionTestCase):
 
+    def assertLogEquals(self, expected, got, msg=None):
+        got = list(got)
+        if len(expected) != len(got):
+            self.assertEquals(expected, got, msg)
+        for (changes1, revnum1), ( changes2, revnum2) in zip(expected, got):
+            self.assertEquals(revnum1, revnum2, msg)
+            self.assertChangedPathsEquals(changes1, changes2, msg)
+
     def setUp(self):
         super(TestLogWalker, self).setUp()
         debug.debug_flags.add("transport")
@@ -58,7 +68,7 @@ class TestLogWalker(SubversionTestCase):
         cb = self.get_commit_editor(repos_url)
         cb.add_dir("branches").close()
         cb.close()
-        
+
         cb = self.get_commit_editor(repos_url)
         cb.add_dir("branches/foo", "trunk").close()
         cb.close()
@@ -67,6 +77,26 @@ class TestLogWalker(SubversionTestCase):
 
         self.assertEqual(2, len(list(walker.iter_changes(["branches/foo"], 3))))
 
+    def test_get_branch_follow_multiple(self):
+        repos_url = self.make_repository("a")
+        cb = self.get_commit_editor(repos_url)
+        cb.add_dir("trunk").close()
+        cb.close()
+
+        cb = self.get_commit_editor(repos_url)
+        cb.add_dir("branches").close()
+        cb.close()
+
+        cb = self.get_commit_editor(repos_url)
+        cb.add_dir("branches/foo", "trunk").close()
+        cb.close()
+
+        walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
+
+        self.assertLogEquals( [({'branches/foo': ('A', 'trunk', 2, 2)}, 3),
+             ({'trunk': ('A', None, -1, 2)}, 1)],
+                (l[:2] for l in walker.iter_changes(["branches/foo", "trunk"], 3, 0)))
+
     def test_get_branch_follow_branch_changing_parent(self):
         repos_url = self.make_repository("a")
         cb = self.get_commit_editor(repos_url)
@@ -85,10 +115,10 @@ class TestLogWalker(SubversionTestCase):
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
 
-        self.assertEquals([
-            ({"branches/abranch": ('A', 'trunk', 2)}, 3),
-            ({"trunk/foo": ('A', None, -1), 
-                           "trunk": ('A', None, -1)}, 1)
+        self.assertLogEquals([
+            ({"branches/abranch": ('A', 'trunk', 2, NODE_DIR)}, 3),
+            ({"trunk/foo": ('A', None, -1, NODE_FILE),
+              "trunk": ('A', None, -1, NODE_DIR)}, 1)
             ], [l[:2] for l in walker.iter_changes(["branches/abranch/foo"], 3)])
 
     def test_get_branch_invalid_revision(self):
@@ -155,7 +185,7 @@ class TestLogWalker(SubversionTestCase):
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
 
         self.assertEqual(1, walker.find_latest_change("", 1))
-    
+
     def test_find_latest_children_root(self):
         repos_url = self.make_repository("a")
         cb = self.get_commit_editor(repos_url)
@@ -164,7 +194,7 @@ class TestLogWalker(SubversionTestCase):
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
 
-        self.assertEqual(1, 
+        self.assertEqual(1,
             walker.find_latest_change("", 1))
 
     def test_find_latest_case(self):
@@ -181,7 +211,7 @@ class TestLogWalker(SubversionTestCase):
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
 
-        self.assertEqual(1, 
+        self.assertEqual(1,
             walker.find_latest_change("branches", 2))
 
     def test_find_latest_parent(self):
@@ -354,7 +384,7 @@ class TestLogWalker(SubversionTestCase):
         t = cb.add_dir("trunk")
         t.add_file("trunk/data").modify()
         cb.close()
-        
+
         cb = self.get_commit_editor(repos_url)
         cb.delete("trunk")
         cb.close()
@@ -365,9 +395,9 @@ class TestLogWalker(SubversionTestCase):
         cb.close()
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
-        self.assertEqual([({"trunk/data": ('A', None, -1),
-                                     "trunk": ('A', None, -1)}, 3)], 
-                                     [l[:2] for l in walker.iter_changes(["trunk"], 3)])
+        self.assertLogEquals([({"trunk/data": ('A', None, -1, NODE_FILE),
+                               "trunk": ('A', None, -1, NODE_DIR)}, 3)],
+                             [l[:2] for l in walker.iter_changes(["trunk"], 3)])
 
     def test_follow_history(self):
         repos_url = self.make_repository("a")
@@ -385,7 +415,8 @@ class TestLogWalker(SubversionTestCase):
         repos_url = self.make_repository("a")
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
 
-        self.assertEqual([({'': ('A', None, -1)}, 0)], [l[:2] for l in walker.iter_changes([""], 0)])
+        self.assertLogEquals([({'': ('A', None, -1, NODE_DIR)}, 0)],
+                [l[:2] for l in walker.iter_changes([""], 0)])
 
     def test_later_update(self):
         repos_url = self.make_repository("a")
@@ -418,10 +449,11 @@ class TestLogWalker(SubversionTestCase):
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
 
         items = [l[:2] for l in walker.iter_changes(["branches/abranch"], 2)]
-        self.assertEqual([({'branches/abranch': ('A', 'trunk', 1)}, 2), 
-                          ({'branches': (u'A', None, -1),
-                                     'trunk/afile': ('A', None, -1), 
-                                     'trunk': (u'A', None, -1)}, 1)], items)
+        self.assertLogEquals([
+            ({'branches/abranch': ('A', 'trunk', 1, NODE_DIR)}, 2),
+            ({'branches': (u'A', None, -1, NODE_DIR),
+                'trunk/afile': ('A', None, -1, NODE_FILE),
+                'trunk': (u'A', None, -1, NODE_DIR)}, 1)], items)
 
     def test_revprop_list(self):
         repos_url = self.make_repository("a")
@@ -472,9 +504,9 @@ class TestLogWalker(SubversionTestCase):
         cb.close()
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
-        self.assertEquals([({'bar/trunk': (u'M', None, -1)}, 3), 
-                           ({'bar': (u'A', 'foo', 1)}, 2), 
-                           ({"foo": ('A', None, -1), 'foo/trunk': (u'A', None, -1)}, 1)], [l[:2] for l in walker.iter_changes(["bar"], 3)])
+        self.assertLogEquals([({'bar/trunk': (u'M', None, -1, NODE_DIR)}, 3),
+                           ({'bar': (u'A', 'foo', 1, NODE_DIR)}, 2),
+                           ({"foo": ('A', None, -1, NODE_DIR), 'foo/trunk': (u'A', None, -1, NODE_DIR)}, 1)], [l[:2] for l in walker.iter_changes(["bar"], 3)])
 
     def test_iter_changes_property_change(self):
         repos_url = self.make_repository('d')
@@ -500,9 +532,11 @@ class TestLogWalker(SubversionTestCase):
         cb.close()
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
-        self.assertEquals([({'trunk': (u'M', None, -1)}, 3), 
-                           ({'trunk': (u'M', None, -1)}, 2), 
-                           ({'trunk/bla': (u'A', None, -1), 'trunk': (u'A', None, -1)}, 1)], [l[:2] for l in walker.iter_changes(["trunk"], 3)])
+        self.assertLogEquals([({'trunk': (u'M', None, -1, NODE_DIR)}, 3),
+                           ({'trunk': (u'M', None, -1, NODE_DIR)}, 2),
+                           ({'trunk/bla': (u'A', None, -1, NODE_FILE),
+                             'trunk': (u'A', None, -1, NODE_DIR)}, 1)],
+                           [l[:2] for l in walker.iter_changes(["trunk"], 3)])
 
     def test_iter_changes_pointless(self):
         repos_url = self.make_repository('d')
@@ -515,12 +549,17 @@ class TestLogWalker(SubversionTestCase):
         cb.close()
 
         walker = self.get_log_walker(transport=SvnRaTransport(repos_url))
-        self.assertEquals([({'trunk': (u'A', None, -1)}, 2)],
+        self.assertLogEquals([({'trunk': (u'A', None, -1, NODE_DIR)}, 2)],
                 [l[:2] for l in walker.iter_changes(["trunk"], 2)])
 
-        self.assertEquals([({'trunk': (u'A', None, -1)}, 2), 
+        self.assertLogEquals([({'trunk': (u'A', None, -1, NODE_DIR)}, 2),
                            ({}, 1),
-                           ({'': ('A', None, -1)}, 0) ],
+                           ({'': ('A', None, -1, NODE_DIR)}, 0) ],
+                [l[:2] for l in walker.iter_changes(None, 2)])
+
+        self.assertLogEquals([({'trunk': (u'A', None, -1, NODE_DIR)}, 2),
+                           ({}, 1),
+                           ({'': ('A', None, -1, NODE_DIR)}, 0) ],
                 [l[:2] for l in walker.iter_changes([""], 2)])
 
 
@@ -531,33 +570,8 @@ class TestCachingLogWalker(TestLogWalker):
         logwalker.cache_dir = os.path.join(self.test_dir, "cache-dir")
 
     def get_log_walker(self, transport):
-        return logwalker.CachingLogWalker(super(TestCachingLogWalker, self).get_log_walker(transport))
-
-
-
-class TestLogCache(TestCase):
-    def setUp(self):
-        super(TestLogCache, self).setUp()
-        self.cache = logwalker.LogCache()
-
-    def test_insert_path(self):
-        self.cache.insert_path(42, u"foo", "A", None, -1)
-        self.assertEquals({"foo": ("A", None, -1)}, self.cache.get_revision_paths(42))
-
-    def test_insert_revprop(self):
-        self.cache.insert_revprop(100, "some", "data")
-        self.assertEquals({"some": "data"}, self.cache.get_revprops(100))
-
-    def test_insert_revinfo(self):
-        self.cache.insert_revinfo(45, True)
-        self.cache.insert_revinfo(42, False)
-        self.assertTrue(self.cache.has_all_revprops(45))
-        self.assertFalse(self.cache.has_all_revprops(42))
-
-    def test_find_latest_change(self):
-        self.cache.insert_path(42, u"foo", "A")
-        self.assertEquals(42, self.cache.find_latest_change("foo", 42))
-        self.assertEquals(42, self.cache.find_latest_change("foo", 45))
+        from bzrlib.plugins.svn.cache.sqlitecache import LogCache
+        return logwalker.CachingLogWalker(super(TestCachingLogWalker, self).get_log_walker(transport), LogCache())
 
 
 
@@ -565,12 +579,12 @@ class DictBasedLogwalkerTestCase(TestCase):
 
     def test_empty(self):
         lw = logwalker.DictBasedLogWalker({}, {})
-        self.assertEquals([({'': ('A', None, -1)}, 0, {})], 
+        self.assertEquals([({'': ('A', None, -1, NODE_DIR)}, 0, {})],
                 list(lw.iter_changes([""], 0)))
 
     def test_simple_root(self):
-        lw = logwalker.DictBasedLogWalker({1:{"/": ('A', None, -1)}}, 
+        lw = logwalker.DictBasedLogWalker({1:{"/": ('A', None, -1, NODE_DIR)}},
                 {1:{"svn:log": "foo"}})
-        self.assertEquals([({'/': ('A', None, -1)}, 1, {'svn:log': 'foo'}),
-            ({'': ('A', None, -1)}, 0, {})], 
+        self.assertEquals([({'/': ('A', None, -1, NODE_DIR)}, 1, {'svn:log': 'foo'}),
+            ({'': ('A', None, -1, NODE_DIR)}, 0, {})],
                 list(lw.iter_changes([""], 1)))
