@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
-from subvertpy import ra
+from subvertpy import NODE_DIR, NODE_FILE, ra
 
 from bzrlib import osutils
 from bzrlib.branch import Branch
@@ -33,14 +33,12 @@ from bzrlib.merge import (
     Merger,
     Merge3Merger,
     )
-from bzrlib.progress import DummyProgress
 from bzrlib.repository import Repository
 from bzrlib.revision import Revision
 from bzrlib.trace import mutter
 from bzrlib.tests import TestCase
 
 from bzrlib.plugins.svn import (
-    format,
     transport,
     )
 from bzrlib.plugins.svn.branch import (
@@ -61,6 +59,7 @@ from bzrlib.plugins.svn.tests import (
     )
 
 
+
 class TestDPush(SubversionTestCase):
 
     def setUp(self):
@@ -103,14 +102,14 @@ class TestDPush(SubversionTestCase):
 
         c = ra.RemoteAccess(self.repos_url)
         (entries, fetch_rev, props) = c.get_dir("", c.get_latest_revnum())
-        self.assertEquals(set(['svn:entry:committed-rev', 
-            'svn:entry:last-author', 'svn:entry:uuid', 
+        self.assertEquals(set(['svn:entry:committed-rev',
+            'svn:entry:last-author', 'svn:entry:uuid',
             'svn:entry:committed-date']), set(props.keys()))
 
         r = self.svndir.find_repository()
         self.assertEquals([r.generate_revision_id(
                 c.get_latest_revnum(),
-                "", 
+                "",
                 r.get_mapping())], revid_map.values())
 
     def test_change_multiple(self):
@@ -132,15 +131,13 @@ class TestDPush(SubversionTestCase):
 
         c = ra.RemoteAccess(self.repos_url)
         (entries, fetch_rev, props) = c.get_dir("", c.get_latest_revnum())
-        self.assertEquals(set(['svn:entry:committed-rev', 
-            'svn:entry:last-author', 'svn:entry:uuid', 
+        self.assertEquals(set(['svn:entry:committed-rev',
+            'svn:entry:last-author', 'svn:entry:uuid',
             'svn:entry:committed-date']), set(props.keys()))
 
         r = self.svndir.find_repository()
-        self.assertEquals(set([r.generate_revision_id(
-                rev,
-                "", 
-                r.get_mapping()) for rev in (c.get_latest_revnum()-1, c.get_latest_revnum())]), 
+        self.assertEquals(set([r.generate_revision_id(rev, "",
+                r.get_mapping()) for rev in (c.get_latest_revnum()-1, c.get_latest_revnum())]),
                 set(revid_map.values()))
 
     def test_dpush_add(self):
@@ -162,8 +159,9 @@ class TestDPush(SubversionTestCase):
         self.assertEquals(set([newid1, newid2]), set(revid_map.keys()))
         repos = self.svndir.find_repository()
         revmeta = repos._revmeta_provider.get_revision("", 3)
-        self.assertEquals(revmeta.get_paths(), {"foo/bliel": ('A', None, -1)})
- 
+        self.assertChangedPathsEquals(
+                {"foo/bliel": ('A', None, -1, NODE_FILE)}, revmeta.get_paths())
+
     def test_diverged(self):
         dc = self.commit_editor()
         foo = dc.open_dir("foo")
@@ -180,8 +178,8 @@ class TestDPush(SubversionTestCase):
         source_branch = self.bzrdir.open_branch()
         source_branch.lock_write()
         try:
-            self.assertRaises(DivergedBranches, 
-                              self.dpush, source_branch, 
+            self.assertRaises(DivergedBranches,
+                              self.dpush, source_branch,
                               svndir.open_branch())
         finally:
             source_branch.unlock()
@@ -237,7 +235,7 @@ class TestPush(SubversionTestCase):
         wt.add('file')
         wt.commit(message="Commit from Bzr")
 
-        self.assertRaises(DivergedBranches, 
+        self.assertRaises(DivergedBranches,
                           svndir.open_branch().pull,
                           self.bzrdir.open_branch())
 
@@ -258,8 +256,8 @@ class TestPush(SubversionTestCase):
           repos.generate_revision_id(2, "", mapping))
         self.assertEqual(repos.generate_revision_id(2, "", mapping),
                         self.svndir.open_branch().last_revision())
-        self.assertEqual("other data", 
-            repos.revision_tree(repos.generate_revision_id(2, "", 
+        self.assertEqual("other data",
+            repos.revision_tree(repos.generate_revision_id(2, "",
                                 mapping)).get_file_text(inv.path2id("foo/bla")))
 
     def test_simple(self):
@@ -288,7 +286,7 @@ class TestPush(SubversionTestCase):
 
         self.svndir.open_branch().pull(self.bzrdir.open_branch())
 
-        self.assertEquals(("Sombody famous", "2002-02-01T23:00:00.000000Z", "Commit from Bzr"), 
+        self.assertEquals(("Sombody famous", "2002-02-01T23:00:00.000000Z", "Commit from Bzr"),
             self.client_log(self.repos_url, 0, 2)[2][1:])
 
     def test_empty_file(self):
@@ -321,7 +319,7 @@ class TestPush(SubversionTestCase):
         self.svndir.open_branch().pull(self.bzrdir.open_branch())
 
         repos = self.svndir.find_repository()
-        mapping = repos.get_mapping() 
+        mapping = repos.get_mapping()
         inv = repos.get_inventory(repos.generate_revision_id(2, "", mapping))
         self.assertTrue(inv.has_filename('south'))
         self.assertEquals('symlink', inv[inv.path2id('south')].kind)
@@ -360,7 +358,7 @@ class TestPush(SubversionTestCase):
         os.mkdir("b")
         repos = self.svndir.sprout("b")
 
-        self.assertEqual(Branch.open("dc").revision_history(), 
+        self.assertEqual(Branch.open("dc").revision_history(),
                          Branch.open("b").revision_history())
 
     def test_fetch_preserves_file_revid(self):
@@ -413,7 +411,7 @@ class TestPush(SubversionTestCase):
 
         self.svndir.open_branch().pull(self.bzrdir.open_branch())
 
-        self.assertEquals((3, "some-rid"), 
+        self.assertEquals((3, "some-rid"),
                 self.svndir.open_branch().last_revision_info())
 
     def test_commit_check_rev_equal(self):
@@ -450,7 +448,7 @@ class TestPush(SubversionTestCase):
 
         mapping = repos.get_mapping()
 
-        self.assertEqual(repos.generate_revision_id(3, "", mapping), 
+        self.assertEqual(repos.generate_revision_id(3, "", mapping),
                         self.svndir.open_branch().last_revision())
 
         inv = repos.get_inventory(repos.generate_revision_id(2, "", mapping))
@@ -464,10 +462,10 @@ class TestPush(SubversionTestCase):
         self.assertEqual(self.svndir.open_branch().revision_history(),
                          self.bzrdir.open_branch().revision_history())
 
-        self.assertEqual(wt.branch.last_revision(), 
+        self.assertEqual(wt.branch.last_revision(),
                 repos.generate_revision_id(3, "", mapping))
         self.assertEqual(
-                wt.branch.repository.get_ancestry(wt.branch.last_revision()), 
+                wt.branch.repository.get_ancestry(wt.branch.last_revision()),
                 repos.get_ancestry(wt.branch.last_revision()))
 
     def test_multiple_diverged(self):
@@ -483,7 +481,7 @@ class TestPush(SubversionTestCase):
         oc.add_dir("adir")
         oc.close()
 
-        self.assertRaises(DivergedBranches, 
+        self.assertRaises(DivergedBranches,
                 lambda: Branch.open(oc_url).pull(self.bzrdir.open_branch()))
 
     def test_different_branch_path(self):
@@ -543,18 +541,17 @@ class TestPush(SubversionTestCase):
         self.svndir.open_branch().pull(wt.branch)
 
         paths = self.svndir.find_repository()._revmeta_provider.get_revision("", 3).get_paths()
-        self.assertEquals({
-            'trunk/comics': (u'R', None, -1),
-            'trunk/comics/bin': (u'A', 'trunk/comics/bin', 2),
-            'trunk/comics/core': (u'A', 'trunk/comics', 2),
-            'trunk/comics/core/bin': (u'D', None, -1)}, paths)
+        self.assertChangedPathsEquals({
+            'trunk/comics': (u'R', None, -1, NODE_DIR),
+            'trunk/comics/bin': (u'A', 'trunk/comics/bin', 2, NODE_DIR),
+            'trunk/comics/core': (u'A', 'trunk/comics', 2, NODE_DIR),
+            'trunk/comics/core/bin': (u'D', None, -1, NODE_DIR)}, paths)
 
 
 class PushNewBranchTests(SubversionTestCase):
 
     def _create_single_rev_bzrwt(self):
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/test': "Tour"})
         bzrwt.add("test")
         revid = bzrwt.commit("Do a commit")
@@ -568,7 +565,7 @@ class PushNewBranchTests(SubversionTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         oldrepos.copy_content_into(newrepos)
         newtree = newrepos.revision_tree(revid)
@@ -597,8 +594,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_single_revision_single_branch(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/test': "Tour"})
         bzrwt.add("test")
         revid = bzrwt.commit("Do a commit")
@@ -638,7 +634,7 @@ class PushNewBranchTests(SubversionTestCase):
 
         self.build_tree({"svnco/baz.txt": "baz"})
         self.client_add("svnco/baz.txt")
-        self.assertEquals(3, 
+        self.assertEquals(3,
                 self.client_commit("svnco", "add yet another file")[0])
         self.client_update("svnco")
 
@@ -653,7 +649,7 @@ class PushNewBranchTests(SubversionTestCase):
         other_rev = repos.generate_revision_id(3, "", mapping)
         wt.lock_write()
         try:
-            merge = Merger.from_revision_ids(DummyProgress(), wt, other=other_rev)
+            merge = Merger.from_revision_ids(None, wt, other=other_rev)
             merge.merge_type = Merge3Merger
             merge.do_merge()
             self.assertEquals(base_revid, merge.base_rev_id)
@@ -663,7 +659,7 @@ class PushNewBranchTests(SubversionTestCase):
         finally:
             wt.unlock()
         self.assertTrue(os.path.exists("bzrco/baz.txt"))
-        self.assertRaises(BzrError, 
+        self.assertRaises(BzrError,
                 lambda: wt.branch.push(Branch.open(repos_url)))
 
     def test_push_replace_existing_branch(self):
@@ -683,7 +679,7 @@ class PushNewBranchTests(SubversionTestCase):
 
         self.build_tree({"svnco/trunk/baz.txt": "baz"})
         self.client_add("svnco/trunk/baz.txt")
-        self.assertEquals(3, 
+        self.assertEquals(3,
                 self.client_commit("svnco", "add yet another file")[0])
         self.client_update("svnco")
 
@@ -697,7 +693,7 @@ class PushNewBranchTests(SubversionTestCase):
         other_rev = repos.generate_revision_id(3, "trunk", mapping)
         wt.lock_write()
         try:
-            merge = Merger.from_revision_ids(DummyProgress(), wt, other=other_rev)
+            merge = Merger.from_revision_ids(None, wt, other=other_rev)
             merge.merge_type = Merge3Merger
             merge.do_merge()
             self.assertEquals(base_revid, merge.base_rev_id)
@@ -755,7 +751,7 @@ class PushNewBranchTests(SubversionTestCase):
         self.assertEquals({"bar2.txt": "side1"}, revmeta.get_text_revisions(r.get_mapping()))
 
         os.mkdir("cpy")
-        cpy = BzrDir.create("cpy", format.get_rich_root_format())
+        cpy = BzrDir.create("cpy")
         cpyrepos = cpy.create_repository()
         r.copy_content_into(cpyrepos)
         check_tree(cpyrepos.revision_tree(mergingrevid))
@@ -765,19 +761,17 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_missing_prefix_error(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/test': "Tour"})
         bzrwt.add("test")
         revid = bzrwt.commit("Do a commit")
         newdir = BzrDir.open(repos_url+"/foo/trunk")
-        self.assertRaises(MissingPrefix, 
+        self.assertRaises(MissingPrefix,
                           lambda: newdir.import_branch(bzrwt.branch))
 
     def test_repeat(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/test': "Tour"})
         bzrwt.add("test")
         revid = bzrwt.commit("Do a commit")
@@ -788,13 +782,12 @@ class PushNewBranchTests(SubversionTestCase):
         self.build_tree({'c/test': "Tour de France"})
         bzrwt.commit("Do a commit")
         newdir = BzrDir.open(repos_url+"/trunk")
-        self.assertRaises(AlreadyBranchError, newdir.import_branch, 
+        self.assertRaises(AlreadyBranchError, newdir.import_branch,
                           bzrwt.branch)
 
     def test_multiple(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/test': "Tour"})
         bzrwt.add("test")
         revid1 = bzrwt.commit("Do a commit")
@@ -807,21 +800,19 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_dato(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/foo.txt': "foo"})
         bzrwt.add("foo.txt")
-        revid1 = bzrwt.commit("Do a commit", 
+        revid1 = bzrwt.commit("Do a commit",
                               committer=u"Adeodato Simó <dato@net.com.org.es>")
         newdir = BzrDir.open(repos_url+"/trunk")
         newdir.import_branch(bzrwt.branch)
-        self.assertEquals(u"Adeodato Simó <dato@net.com.org.es>", 
+        self.assertEquals(u"Adeodato Simó <dato@net.com.org.es>",
                 Repository.open(repos_url).get_revision(revid1).committer)
 
     def test_utf8_commit_msg(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/foo.txt': "foo"})
         bzrwt.add("foo.txt")
         revid1 = bzrwt.commit(u"Do á commït")
@@ -832,8 +823,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_kind_change_file_to_directory(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/foo.txt': "foo"})
         bzrwt.add("foo.txt")
         revid1 = bzrwt.commit(u"somecommit")
@@ -846,8 +836,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_kind_change_directory_to_file(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/foo.txt/bar': "foo"})
         bzrwt.add("foo.txt")
         revid1 = bzrwt.commit(u"somecommit")
@@ -881,7 +870,7 @@ class PushNewBranchTests(SubversionTestCase):
         self.assertEquals(revid2, newbranch.last_revision())
         mapping = svnrepos.get_mapping()
         self.assertEquals([
-            svnrepos.generate_revision_id(1, "trunk", mapping) 
+            svnrepos.generate_revision_id(1, "trunk", mapping)
             , revid1, revid2], newbranch.revision_history())
 
     def test_push_overwrite(self):
@@ -929,8 +918,7 @@ class PushNewBranchTests(SubversionTestCase):
         bzrdir = BzrDir.open(repos_url+"/trunk").sprout("d1")
         bzrwt1 = bzrdir.open_workingtree()
 
-        bzrwt2 = BzrDir.create_standalone_workingtree("d2", 
-            format=format.get_rich_root_format())
+        bzrwt2 = BzrDir.create_standalone_workingtree("d2")
 
         self.build_tree({'d1/myfile': "Tour"})
         bzrwt1.add("myfile")
@@ -951,8 +939,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_complex_rename(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/registry/generic.c': "Tour"})
         bzrwt.add("registry")
         bzrwt.add("registry/generic.c")
@@ -981,8 +968,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_rename_dir_changing_contents(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/registry/generic.c': "Tour"})
         bzrwt.add("registry", "dirid")
         bzrwt.add("registry/generic.c", "origid")
@@ -1008,9 +994,7 @@ class PushNewBranchTests(SubversionTestCase):
         check(copybranch)
 
     def _create_bzrwt_with_changed_root(self):
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
-
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({"c/foo": "bla"})
         bzrwt.add(["foo"])
         revid1 = bzrwt.commit("Initial")
@@ -1035,8 +1019,8 @@ class PushNewBranchTests(SubversionTestCase):
         bzrwt, old_ie, new_ie, foo_ie, revid1, revid2 = self._create_bzrwt_with_changed_root()
         newdir = BzrDir.open(repos_url+"/trunk")
         newbranch = newdir.import_branch(bzrwt.branch)
-        self.assertEquals({"trunk": ("R", None, -1), 
-                           "trunk/foo": ("A", "trunk/foo", 1)},
+        self.assertChangedPathsEquals({"trunk": ("R", None, -1, NODE_DIR),
+                           "trunk/foo": ("A", "trunk/foo", 1, NODE_FILE)},
             newbranch.repository._revmeta_provider.get_revision("trunk", 2).get_paths())
         tree1 = newbranch.repository.revision_tree(revid1)
         tree2 = newbranch.repository.revision_tree(revid2)
@@ -1045,7 +1029,7 @@ class PushNewBranchTests(SubversionTestCase):
         self.assertEquals(tree1.path2id("foo"), foo_ie.file_id)
         self.assertEquals(tree2.path2id("foo"), foo_ie.file_id)
 
-        self.assertEquals(bzrwt.branch.revision_history(), 
+        self.assertEquals(bzrwt.branch.revision_history(),
                           newbranch.revision_history())
 
     def test_change_root_fetch(self):
@@ -1057,14 +1041,15 @@ class PushNewBranchTests(SubversionTestCase):
 
         oldrepos = Repository.open(repos_url)
         oldrepos.set_layout(TrunkLayout(0))
-        dir = BzrDir.create("f", format.get_rich_root_format())
+        dir = BzrDir.create("f")
         newrepos = dir.create_repository()
         oldrepos.copy_content_into(newrepos)
 
         log = self.client_log(repos_url, 2, 0)
-        self.assertEquals({'/trunk': ('A', None, -1), 
-                           '/trunk/foo': ('A', None, -1)}, log[1][0])
-        self.assertEquals({'/trunk': ('R', None, -1), 
+        self.assertEquals({'/trunk': ('A', None, -1),
+                           '/trunk/foo': ('A', None, -1)},
+                           log[1][0])
+        self.assertEquals({'/trunk': ('R', None, -1),
                            '/trunk/foo': ('A', '/trunk/foo', 1)}, log[2][0])
 
         tree1 = newrepos.revision_tree(revid1)
@@ -1076,8 +1061,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_rename_dir(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/registry/generic.c': "Tour"})
         bzrwt.add("registry", "dirid")
         bzrwt.add("registry/generic.c", "origid")
@@ -1097,17 +1081,16 @@ class PushNewBranchTests(SubversionTestCase):
         copybranch = Branch.open("n")
         check(copybranch)
 
-    def test_push_non_lhs_parent(self):        
+    def test_push_non_lhs_parent(self):
         from bzrlib.debug import debug_flags
         debug_flags.add("commit")
         debug_flags.add("fetch")
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/registry/generic.c': "Tour"})
         bzrwt.add("registry")
         bzrwt.add("registry/generic.c")
-        revid1 = bzrwt.commit("Add initial directory + file", 
+        revid1 = bzrwt.commit("Add initial directory + file",
                               rev_id="initialrevid")
 
         # Push first branch into Subversion
@@ -1136,13 +1119,13 @@ class PushNewBranchTests(SubversionTestCase):
         self.build_tree({'c/registry/generic.c': "de"})
         revid2 = bzrwt.commit("Change something", rev_id="changerevid")
 
-        # Merge 
+        # Merge
         self.build_tree({'c/registry/generic.c': "France"})
         bzrwt.add_pending_merge(merge_revid)
         revid3 = bzrwt.commit("Merge something", rev_id="mergerevid")
 
         trunk = Branch.open(repos_url + "/branches/foo")
-        self.assertRaises(AppendRevisionsOnlyViolation, trunk.pull, 
+        self.assertRaises(AppendRevisionsOnlyViolation, trunk.pull,
             bzrwt.branch)
         trunk.get_config().set_user_option('append_revisions_only', 'False')
         trunk.pull(bzrwt.branch)
@@ -1151,8 +1134,7 @@ class PushNewBranchTests(SubversionTestCase):
 
     def test_complex_replace_dir(self):
         repos_url = self.make_repository("a")
-        bzrwt = BzrDir.create_standalone_workingtree("c", 
-            format=format.get_rich_root_format())
+        bzrwt = BzrDir.create_standalone_workingtree("c")
         self.build_tree({'c/registry/generic.c': "Tour"})
         bzrwt.add(["registry"], ["origdir"])
         bzrwt.add(["registry/generic.c"], ["file"])
@@ -1189,8 +1171,9 @@ class PushNewBranchTests(SubversionTestCase):
         try:
             wt.apply_inventory_delta([
                 ("", None, wt.inventory.root.file_id, None),
-                ("mysubdir", "", wt.inventory.path2id("mysubdir"), 
-                    InventoryDirectory(wt.inventory.path2id("mysubdir"), "", None))])
+                ("mysubdir", "", wt.inventory.path2id("mysubdir"),
+                    InventoryDirectory(wt.inventory.path2id("mysubdir"), "",
+                        None))])
             os.rename("dc/mysubdir/myfile", "dc/myfile")
             osutils.rmtree("dc/mysubdir")
         finally:
@@ -1201,7 +1184,8 @@ class PushNewBranchTests(SubversionTestCase):
         self.assertEquals(svnbranch.last_revision(), wt.branch.last_revision())
         self.assertEquals(["myfile"], svndir.root_transport.list_dir("."))
         paths = svnbranch.repository._revmeta_provider._log.get_revision_paths(2)
-        self.assertEquals(('R', "trunk/mysubdir", 1), paths['trunk'])
+        self.assertChangedPathEquals(('R', "trunk/mysubdir", 1, NODE_DIR),
+                paths['trunk'])
 
     def test_push_pointless(self):
         repos_url = self.make_repository("a")
@@ -1216,14 +1200,15 @@ class PushNewBranchTests(SubversionTestCase):
 
         wt = bzrdir.open_workingtree()
         wt.lock_write()
-        try: 
+        try:
             wt.commit("This is pointless.")
             svnbranch = svndir.open_branch()
             svnbranch.pull(wt.branch)
-            self.assertEquals(svnbranch.last_revision(), wt.branch.last_revision())
+            self.assertEquals(svnbranch.last_revision(),
+                wt.branch.last_revision())
         finally:
             wt.unlock()
- 
+
 
 class TestPushTwice(SubversionTestCase):
     def test_push_twice(self):
